%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% M-file to display mode shapes using OpenSEES output for skew bridge model
%
% Summary: 
% Can plot individual modes or several modes simultaneously
%
% Written by N.Kwong (nealsimonkwong@berkeley.edu)
% Date Modified: 23 Nov 2010
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ----------------------DEFINITIONS---------------------------------------
% modalDirectory  = specifies path to locate modal output 
% numModes        = max number of modes script will deal with
% modecolor       = matrix of colors to display modes (row 1 for mode 1,etc)
% amp             = magnifies nodal movements to better display mode shapes

%% User Input 
clear all; clc; close all;

modalDirectory = 'J:\MPS\Skew Bridge\OpenSees_Skw\EigOutput';
cd(modalDirectory)

numModes = 3;
modecolor = [0 0 1;0 1 0;1 0 0;0 1 1;1 0 1;1 1 0;1 127/255 0;150/255 75/255 0;128/255 0 128/255;1 192/255 203/255];
amp = 75;  

pFlag = input('Plot all modes simultaneously? (y/n): ', 's');

if pFlag == 'n'
    modeID = input('Plot which mode? (1,2,etc): ', 's');
    modeID = str2num(modeID);
    modeID = modeID - 1;
end

%% Set up original geometry
geo_org = load('origGeo.txt');
% size(geo_org)

% Deck
x_org(1:81) = geo_org(1:81,2);
y_org(1:81) = geo_org(1:81,3);
z_org(1:81) = geo_org(1:81,4);

% North bent
x_org(82:90) = geo_org(82:90,2);
y_org(82:90) = geo_org(82:90,3);
z_org(82:90) = geo_org(82:90,4);

% South bent
x_org(91:99) = geo_org(91:99,2);
y_org(91:99) = geo_org(91:99,3);
z_org(91:99) = geo_org(91:99,4);

%% Extract mode shape
mode = zeros((3*numModes),99);

for i=0:(numModes-1)
    xfilename = ['Mode_' num2str(i+1) 'x.out'];
    yfilename = ['Mode_' num2str(i+1) 'y.out'];
    zfilename = ['Mode_' num2str(i+1) 'z.out'];
    
    file = load(xfilename);
    mode((3*i+1),:) = amp*file(1,:);
    file = load(yfilename);
    mode((3*i+2),:) = amp*file(1,:);
    file = load(zfilename);
    mode((3*i+3),:) = amp*file(1,:);
end

%% Plot original geometry
% Deck
plot3(x_org(1:81),y_org(1:81),z_org(1:81),'ko-')
grid on; hold on;

% North bent
plot3(x_org(82:90),y_org(82:90),z_org(82:90),'ko-')
% South bent
plot3(x_org(91:99),y_org(91:99),z_org(91:99),'ko-')
% Rigid beam
plot3(x_org([90 99]),y_org([90 99]),z_org([90 99]),'ko-')

%% Plot mode shapes
set(gca,'FontSize',14);

if pFlag == 'y';
    for j=0:(numModes-1)
        xdef = x_org+mode((3*j+1),:);
        ydef = y_org+mode((3*j+2),:);
        zdef = z_org+mode((3*j+3),:);

        % Deck
        col = modecolor(j+1,:);
        hd = plot3(xdef(1:81),ydef(1:81),zdef(1:81),'Color',col);
        % North bent
        hnb = plot3(xdef(82:90),ydef(82:90),zdef(82:90),'Color',col);
        % South bent
        hsb = plot3(xdef(91:99),ydef(91:99),zdef(91:99),'Color',col);
        % Rigid beam
        hrb = plot3(xdef([90 99]),ydef([90 99]),zdef([90 99]),'Color',col);

        set(hd,'LineWidth',5);
        set(hnb,'LineWidth',5);
        set(hsb,'LineWidth',5);
        set(hrb,'LineWidth',5);
    end
else
    
    xdef = x_org+mode((3*modeID+1),:);
    ydef = y_org+mode((3*modeID+2),:);
    zdef = z_org+mode((3*modeID+3),:);

    % Deck
    col = modecolor(modeID+1,:);
    hd = plot3(xdef(1:81),ydef(1:81),zdef(1:81),'Color',col);
    % North bent
    hnb = plot3(xdef(82:90),ydef(82:90),zdef(82:90),'Color',col);
    % South bent
    hsb = plot3(xdef(91:99),ydef(91:99),zdef(91:99),'Color',col);
    % Rigid beam
    hrb = plot3(xdef([90 99]),ydef([90 99]),zdef([90 99]),'Color',col);

    set(hd,'LineWidth',5);
    set(hnb,'LineWidth',5);
    set(hsb,'LineWidth',5);
    set(hrb,'LineWidth',5);
end