%% ------------------------------------------------------------------------
% Plot Benchmark EDPs 
%
% Summary: This script is to be applied when current MATLAB directory
% contains the "output" folder generated by OpenSEES model. The folder
% should contain the workspace file post_process.mat. 
% 
% Written by E. Kalkan
% Modified by: N.Kwong (nealsimonkwong@berkeley.edu)
% Date Modified: Nov 2010

%% ----------------------DEFINITIONS---------------------------------------
% medRDR        = median drift ratio among all records (in %)
% medCol_Rot    = median column plastic rotation among all records (in rad)

%% User Input
clear all; clc; close all; 

% Double check directory for post_process.mat file
load('post_process.mat');

%% Compute median values
medRDR = geomean(RDR')*100; 
medCol_Rot = geomean(PlasticRot_Trans_Max');

%% Plot Benchmark EDPs from all records along with median values
figure(1); orient tall; clf; 
set(gcf,'position',[300 283 650 300]);
set(gca,'TickLength',[.0025 .0025]);
subplot1(1,2,'Gap',[0.11 0.01]); 

% Plot drift ratios
subplot1(1);
    plot(NodalDisp_Trans_Max/h*100,'o','MarkerSize',5,...
    'MarkerEdgeColor','b','MarkerFaceColor','b');
    X = [0 21]; Y = [medRDR medRDR];
    plot(X, Y,'--r','LineWidth',2.0);
    axis([1 21 0 5]);
    ylabel('Deck Drift Ratio (%)','FontSize',[10],'FontWeight','bold'); 
    xlabel('Ground Motion Number','FontSize',[10],'FontWeight','bold'); 
    %set(gca,'Ytick',[0:6]);
    set(gca,'fontsize',9);axis square;
    %set(gca,'xtick',[0:0.01:0.1]);
    %set(gca,'YTickLabel',{'0','','2','','4','','6'},'fontsize',9);    
    X1 = [13 16]; X2 = [14.5, 14.5];
    Y1 = [4.7 4.7]; Y2 = [4.3, 4.3]; 
    plot(X1,Y1,'--','Color','r','LineWidth',2.0);
    text('pos',[X1(2)+0.5 Y1(2)],'str','Median','Color','k','FontSize',[9],'FontWeight','normal');            
    plot(X2,Y2,'Linestyle','o','MarkerSize',5,...
        'MarkerEdgeColor','b','MarkerFaceColor','b');
    text('pos',[X1(2)+0.5 Y2(2)],'str','ith GM','Color','k','FontSize',[9],'FontWeight','normal');                        

% Plot plastic rotations
subplot1(2);    
    set(gca,'fontsize',9);axis square;
    Y = [medCol_Rot medCol_Rot];
    plot(X, Y,'--r','LineWidth',2.0);
    plot(PlasticRot_Trans_Max,'o','MarkerSize',5,...
    'MarkerEdgeColor','b','MarkerFaceColor','b');
    axis([1 21 0 0.04]);
    set(gca,'YTickLabel',{'0','0.01','0.02','0.03','0.04'},'fontsize',9);
    ylabel('Column Plastic Rot. (rad)','FontSize',[10],'FontWeight','bold'); 
    xlabel('Ground Motion Number','FontSize',[10],'FontWeight','bold'); 
