%% ------------------------------------------------------------------------
% Plot EDPs from MPS sets, along with their median values, and compare with
% median/target values from benchmark EDPs
%
% Summary: After loading benchmark EDPs and extracting the median values as
% target values, the workspace file is overwritten by those from the MPS
% sets of ground motions. The median values from these sets are computed
% and compared visually with target values.
% 
% Written by E. Kalkan
% Modified by: N.Kwong (nealsimonkwong@berkeley.edu)
% Date Modified: Nov 2010

%% ----------------------DEFINITIONS---------------------------------------
% fpath_BM      = specifies location of workspace file for benchmark EDPs
% fpath_MPS     = specifies location of sets of records scaled by MPS 
% n             = number of sets of records scaled by MPS
% medRDR        = median drift ratio among all records (in %)
% medCol_Rot    = median column plastic rotation among all recrods (in rad)

%% User Input
clear all; clc; close all; 

fpath_BM = 'J:\MPS\Skew Bridge\NLRHA\Benchmark\Skew_Unscaled\post_process.mat';
fpath_MPS = 'J:\MPS\Skew Bridge\NLRHA\Sets\';

n = input('Enter Number of Sets: ', 's');   
n = str2num(n);

%% Extract benchmark EDP values for comparison
load(fpath_BM);
medRDR = geomean(RDR')*100; 
target_medRDR = medRDR';
target_medCol_Rot = geomean(PlasticRot_Trans_Max');

%% Plot EDPs from all MPS sets of records
figure(1); orient tall; clf; 
set(gcf,'position',[300 283 220*n 450]);
set(gca,'TickLength',[.0025 .0025]);

subplot1(2,n,'Gap',[0.01 0.01]); 

for w = 1:n;
    titl = strcat('GM Set-',num2str(w));
    filename = strcat(fpath_MPS,'Set-',num2str(w),'\Skew_Unscaled\post_process.mat');
    load (filename);
    clear line;
    medRDR = geomean(RDR')*100; 
    medRDR = medRDR';
    medCol_Rot = geomean(PlasticRot_Trans_Max');
    
    subplot1(w);
        X = [0 7]; Y = [medRDR medRDR]; 
        Y_target = [target_medRDR target_medRDR];
        plot(X, Y_target,'-k','LineWidth',2.0);
        plot(X, Y,'--r','LineWidth',2.0);
        plot(NodalDisp_Trans_Max/h*100,'o','MarkerSize',5,...
        'MarkerEdgeColor','b','MarkerFaceColor','b');
        axis([1 7 0 5]);        
        %set(gca,'Ytick',[0:6]);
        set(gca,'fontsize',9);axis square;
        set(gca,'xtick',[1:7]);
        %set(gca,'YTickLabel',{'0','','2','','4','','6'},'fontsize',9);
        text('pos',[3.2 5.3],'str',titl,'FontSize',[9],'FontWeight','bold'); 
        if w == 1;
           ylabel('Deck Drift Ratio (%)','FontSize',[10],'FontWeight','bold');         
           %LEGEND
            X1 = [3.6 4.6];
            X2 = [4.8 5.7];
            X3 = [4.1 4.1];
            Y1 = [4.7 4.7]; Y2 = [4.3 4.3]; Y3 = [3.8 3.8]; Y4 = [3.4 3.4];
            line(X1,Y1,'Color','k','LineWidth',2.0);
            text('pos',[X1(2)+0.2 Y1(2)],'str','Benchmark','Color','k','FontSize',[9],'FontWeight','normal');            
            text('pos',[X1(2)+0.2 Y2(2)],'str','MPS','Color','k','FontSize',[9],'FontWeight','normal');                
            line(X2,Y2-0.2,'Color','k','LineWidth',1);
            plot(X1,Y3,'--','Color','r','LineWidth',2.0);
            text('pos',[X1(2)+0.2 Y3(2)],'str','Median','Color','k','FontSize',[9],'FontWeight','normal');            
            line(X3,Y4,'Linestyle','o','MarkerSize',5,...
        'MarkerEdgeColor','b','MarkerFaceColor','b');
            text('pos',[X1(2)+0.2 Y4(2)],'str','ith GM','Color','k','FontSize',[9],'FontWeight','normal');                        
        end
    subplot1(w+3);
        set(gca,'fontsize',9);axis square;
        Y = [medCol_Rot medCol_Rot];
        Y_target = [target_medCol_Rot target_medCol_Rot];
        plot(X, Y,'--r','LineWidth',2.0);
        plot(X, Y_target,'-k','LineWidth',2.0);
        plot(PlasticRot_Trans_Max,'o','MarkerSize',5,...
        'MarkerEdgeColor','b','MarkerFaceColor','b');
        axis([1 7 0 0.04]);
        %set(gca,'YTickLabel',{'0','0.01','0.02','0.03','0.04'},'fontsize',9);
        set(gca,'xtick',[1:7]);
        if w == 1;
            ylabel('Column Plastic Rot. (rad)','FontSize',[10],'FontWeight','bold'); 
        elseif w == 2;
            xlabel('Ground Motion Number','FontSize',[10],'FontWeight','bold');         
        end                
end
