% This file is used in response_TCL_NGA.m
% Function to extract info from .AT2 files and save into matlab variables
% Variables are saved in GMinfo.mat workspace file
% Note: createTCL function uses the workspace file from this function
%
% Written by: E.Kalkan
% Modified by: N.Kwong
% Date Modified: 09 Nov 2010
%% ----------------------DEFINITIONS---------------------------------------
% filename  = name of current record
% accFile   = file identifier indicating current record
% convF     = conversion factor from units of g to desired units
% SF_manual = scale factor to modify .AT2 motions before testing scaling
%             procedure (used if original motions are insufficient to drive
%             into inelastic range
% c_name       = name of component of record 
% eq_date      = date of earthquake
% station_name = name or recording station
% filters      = filter info
% npoint       = total number of data points
% dt           = time step for record
% gacc         = acceleration data from file
% filename_c   = name of GM file without file extensions
        
%% ------------------------------------------------------------------------
function readGMat2(filename,accFile,convF,SF_manual)
% READ HEADING TEXT LINES of .at2 file
% Use string locating commands to precisely extract info
% Note: Sensitive to location of words in .at2 files
for i = 1:4;
    line = fgets(accFile);
    if i == 2;
        divider1 = instrrev (line, ',', 2)-1;
        line2 = line(divider1:end);
        divider2 = instrrev (line2, ',', 1) + divider1 + 1;
        c_name = line(divider2:divider2+3);
        eq_date = line(1:divider1);
        station_name = line(divider1+2:divider2-3);
    elseif i == 3;
        filters = line(56:79);
    elseif i == 4;
        npoint = line(2:7);
        dt = line(11:17);
    end
end

dt = str2num(dt);
npoint = str2num(npoint);
fprintf('Npoint = %5.0f; dt = %5.4f   \n',npoint,dt);
gacc = fscanf(accFile,'%15e ',npoint);
gacc = gacc*convF*SF_manual;     
% Get name of file without extension
filename_c = filename(1:length(filename)-6);

save GMinfo.mat c_name eq_date station_name filters npoint dt gacc filename_c
end
