% TRIPART
% function tripart(fignumber,PSV,PGA,PGV,PGD)
%
% Description:  Tripartite plot of Response Spectrum
%               It also construct 5 percent damped Newmark & Hall spectrum
%               see Chopra p. 221
% Input: 
%      fignumber - figure number  
%      PSV spectrum - should be in cm/sec (a vector)
%      T - spectral period array          (a vector)
%      PGA - in cm/sec
%      PGV - in cm/sec
%      PGD - in cm
%
% Note: PSV spectrum should be computed at exact period sequence of T 
%      
% T = [0.01	0.02	0.022	0.025	0.029	0.03	0.032	0.035	0.036
% 0.04	0.042	0.044	0.045	0.046	0.048	0.05	0.055	0.06	
% 0.065	0.067	0.07	0.075	0.08	0.085	0.09	x0.095	0.1	0.11	
% 0.12	0.125 0.13	0.133	0.14	0.15	0.16	0.17	0.18	0.19	
% 0.2	0.22	0.24	0.25	0.26	0.28	0.29	0.3	0.32	0.34
% 0.35	0.36	0.38	0.4	0.42	0.44	0.45	0.46	0.48	0.5	
% 0.55	0.6	0.65	0.667	0.7	0.75	0.8	0.85	0.9	0.95	1	1.1	
% 1.2	1.3	1.4	1.5	1.6	1.7	1.8	1.9	2	2.2	2.4	2.5	2.6	2.8	3	
% 3.2	3.4	3.5	3.6	3.8	4	4.2	4.4	4.6	4.8	5 7.5 10 20 33 50];
% Last Revised Nov. 14 - 2007
% Copyright (c) 2007 by E. Kalkan

function tripart(fignumber, PSV, PGA, PGV, PGD);
 T = [0.01	0.02	0.022	0.025	0.029	0.03	0.032	0.035	0.036 ...
 0.04	0.042	0.044	0.045	0.046	0.048	0.05	0.055	0.06 ...	
 0.065	0.067	0.07	0.075	0.08	0.085	0.09	0.095	0.1	0.11 ...	
 0.12	0.125 0.13	0.133	0.14	0.15	0.16	0.17	0.18	0.19 ...	
 0.2	0.22	0.24	0.25	0.26	0.28	0.29	0.3	0.32	0.34 ...
 0.35	0.36	0.38	0.4	0.42	0.44	0.45	0.46	0.48	0.5 ...	
 0.55	0.6	0.65	0.667	0.7	0.75	0.8	0.85	0.9	0.95	1	1.1	...
 1.2	1.3	1.4	1.5	1.6	1.7	1.8	1.9	2	2.2	2.4	2.5	2.6	2.8	3 ...	
 3.2	3.4	3.5	3.6	3.8	4	4.2	4.4	4.6	4.8	5 7.5 10 20 33 50];

SF = 2.1;

figure(fignumber); orient tall; clf; loglog(T,PSV,'LineWidth',1.5); hold;
set(gca,'TickLength',[.02 .02]); 
axis square;
set(gcf,'position',[200 300 450 450]);
axis([0.01 100 0.1 1200]);
xbox = [0.01 0.01 0.01 100; 100 100 0.01 100];
ybox = [0.1 1200 0.1 0.1; 0.1 1200 1200 1200];
line(xbox, ybox,'LineWidth',1.5);

xlabel('Period (s),Tn','FontSize',[12],'FontWeight','bold');
ylabel('Pseudo Vel. (cm/s)','FontSize',[12],'FontWeight','bold');

text('FontSize',[12],'FontWeight','bold','pos',[4 4],'str','Pseudo Acc. (cm/s)','rot',[-45]);
text('FontSize',[12],'FontWeight','bold','pos',[20 150],'str','Disp. (cm)','rot',[+45]);
%text('FontSize',[12],'FontWeight','bold','pos',[1 700*SF],'str','S p e c t r a l   R e g i o n s', 'HorizontalAlign','Center');

pi2 = pi + pi;
for i = 1:3;
    x = pi2*10^(i-3); y1=x*10; y2=10^(-i+4)/pi2;
    line([x 0.01],[0.1 y1]);
    line([x 100],[0.1 y2]);
    line([x 0.01],[1200 y2]);
    line([x 100],[1200 y1]);
end

    x=pi2*10; y1=x*10; y2=10^(-log10(pi2));
    line([x; 0.01],[0.1; y1],'LineStyle','-');
    line([x; 0.01],[1200;y2],'LineStyle','-');
for i=1:4;
    x1 = pi2*10^(i-3); x2=x1*10^(-1/2); y1=10^(i-1); y2=y1*10^(-1/2);
    z1 = 10^(-i+3); z2=z1*10^(1/2);
    d1=1.15; d2=1.20; d3=1.13; d4=1.28; d5=1.56; d6=1.19; d7=1.42; d8=1.08;
    s1=int2str(2*i-4); s2=int2str(2*i-5);
    s3=int2str(-2*i+3); s4=int2str(-2*i+4);

    if i~= 4;
        text('pos',[x1/d1 y1/d2],'str','10','rot',[-45]);
        text('pos',[x1/d5 z1/d6],'str','10','rot',[+45]);
        text('FontSize',[8],'pos',[x1*d3 y1/d4],'str',s1,'rot',[-45]);
        text('FontSize',[8],'pos',[x1/d7 z1*d8],'str',s3,'rot',[+45]);
        
        if i~= 1;
            text('pos',[x2/d1 y2/d2],'str','10','rot',[-45]);
            text('pos',[x2/d5 z2/d6],'str','10','rot',[+45]);
            text('FontSize',[8],'pos',[x2*d3 y2/d4],'str',s2,'rot',[-45]);
            text('FontSize',[8],'pos',[x2/d7 z2*d8],'str',s4,'rot',[+45]);
        end
    end
    
    for j=1:9;
        d9=1.07; if j==1; d9=1.13; end
        
        x11=x2*j^(1/2);  x12=x11/d9; y11=y2*j^(1/2); y12=y11*d9;
        x21=x1*j^(1/2);  x22=x21/d9; y21=y1*j^(1/2); y22=y21*d9;
        x31=x1*j^(-1/2); x32=x31*d9; z11=z1*j^(1/2); z12=z11*d9;
        x41=x2*j^(-1/2); x42=x41*d9; z21=z2*j^(1/2); z22=z21*d9;
        
        line([x11 x12], [y11 y12]);
        line([x21 x22], [y21 y22]);
        line([x31 x32], [z11 z12]);
        line([x41 x42], [z21 z22]);
    end
end

% Construct Riddell and Newmark (1979) spectrum;
alfa_a = 2.12; 
alfa_v = 1.65;
alfa_d = 1.39;

for k = 1:length(T);
        omega(k) = 2*pi/T(k);
end
for i = 1:length(T);
    Vprime(i) = PGA/omega(i)*alfa_a;
    Vp(i) =  PGA/omega(i);
    Vprime2(i) = PGD*omega(i)*alfa_d;
    Vp2(i) = PGD*omega(i);
end
for i = 1:length(T);
    if(Vprime(i) >= PGV*alfa_v);
        c = i;
        break
    end
end
for i = 1:length(T);
    if(Vprime2(i) <= PGV*alfa_v);
        d = i;
        break
    end
end
a = 6;
b = 29;
e = 98;
f = 100;
h = length(T);

size(Vp2)

loglog(T(1:a),Vp(1:a),'r--','LineWidth',1.5);
loglog(T(f:h),Vp2(f:h),'r--','LineWidth',1.5);
line([T(c) T(d)],[PGV*alfa_v PGV*alfa_v],'LineStyle','--','Color','r','LineWidth',1.5);

loglog(T(b:c-1),Vprime(b:c-1),'r--','LineWidth',1.5);
loglog(T(d:e),Vprime2(d:e),'r--','LineWidth',1.5);
line([T(a) T(b)], [Vp(a) Vprime(b)],'LineStyle','--','Color','r','LineWidth',1.5);
line([T(e) T(f)], [Vprime2(e) Vp2(f)],'LineStyle','--','Color','r','LineWidth',1.5);

% Corner Freqency Plotss
line([T(a) T(a)],[0.01 Vp(a)],'LineStyle',':','Color','g','LineWidth',1.5);
line([T(b) T(b)],[0.01 Vprime(b)],'LineStyle',':','Color','g','LineWidth',1.5);
line([T(c) T(c)],[0.01 PGV*alfa_v],'LineStyle',':','Color','g','LineWidth',1.5);
line([T(d) T(d)],[0.01 PGV*alfa_v],'LineStyle',':','Color','g','LineWidth',1.5);
line([T(e) T(e)],[0.01 Vprime2(e)],'LineStyle',':','Color','g','LineWidth',1.5);
line([T(f) T(f)],[0.01 Vp2(f)],'LineStyle',':','Color','g','LineWidth',1.5);


% Spectral Regions
line([0.01 100], [400 400]*SF,'LineStyle','-','Color','r');
line([T(c) T(c)], [360 440]*SF,'Color','r');
line([T(d) T(d)], [360 440]*SF,'Color','r');

text('FontSize',[10],'FontWeight','bold','pos',[0.1 470*SF],'str','Acceleration', 'HorizontalAlign','Center');
text('FontSize',[10],'FontWeight','bold','pos',[0.1 350*SF],'str','sensitive', 'HorizontalAlign','Center');

text('FontSize',[10],'FontWeight','bold','pos',[1.5 470*SF],'str','Velocity', 'HorizontalAlign','Center');
text('FontSize',[10],'FontWeight','bold','pos',[1.5 350*SF],'str','sensitive', 'HorizontalAlign','Center');

text('FontSize',[10],'FontWeight','bold','pos',[15 470*SF],'str','Displacement', 'HorizontalAlign','Center');
text('FontSize',[10],'FontWeight','bold','pos',[15 350*SF],'str','sensitive', 'HorizontalAlign','Center');

text('FontSize',[10],'FontWeight','bold','pos',[T(a) 0.2],'str','Ta', 'HorizontalAlign','Center');
text('FontSize',[10],'FontWeight','bold','pos',[T(a) 0.13],'str',T(a), 'HorizontalAlign','Center');

text('FontSize',[10],'FontWeight','bold','pos',[T(b) 0.2],'str','Tb', 'HorizontalAlign','Center');
text('FontSize',[10],'FontWeight','bold','pos',[T(b) 0.13],'str',T(b), 'HorizontalAlign','Center');

text('FontSize',[10],'FontWeight','bold','pos',[T(c) 0.2],'str','Tc', 'HorizontalAlign','Center');
text('FontSize',[10],'FontWeight','bold','pos',[T(c) 0.13],'str',T(c), 'HorizontalAlign','Center');

text('FontSize',[10],'FontWeight','bold','pos',[T(d) 0.2],'str','Td', 'HorizontalAlign','Center');
text('FontSize',[10],'FontWeight','bold','pos',[T(d) 0.13],'str',T(d), 'HorizontalAlign','Center');

text('FontSize',[10],'FontWeight','bold','pos',[T(e) 0.2],'str','Te', 'HorizontalAlign','Center');
text('FontSize',[10],'FontWeight','bold','pos',[T(e) 0.13],'str',T(e), 'HorizontalAlign','Center');

text('FontSize',[10],'FontWeight','bold','pos',[T(f) 0.2],'str','Tf', 'HorizontalAlign','Center');
text('FontSize',[10],'FontWeight','bold','pos',[T(f) 0.13],'str',T(f), 'HorizontalAlign','Center');

return

