%% ------------------------------------------------------------------------
% Higher-mode Considerations:
%
% Manually find all SFs from the "sets" folders in \Sets_Exact and collect
% them in a text file in the GMs folder for x and y. Current directory
% should be ...\Sets_Exact\Target_Exact
%
% 1) Get target spectral displacements for x and y (e.g. median spectra)
% 2) Get spectral displacement for x and y for each GM record
% 3) Get SF from "exact" method for x and y
% 4) Peak def. is D2 = product of results from 2) and 3) for x and y
% 5) Based on E2, rank records and determine final set
% 6) Find output from sets manually and create new folders for set 4
% 7) Post process like all other sets
%
% Written by: N.Kwong
% Date modified: 18 Aug 2010
%% ------------------------------------------------------------------------
clear all; clc; close all;

% INPUT DATA ----------------------------------------------
nGM=21; 
SF = 1.0; %(For individual records)
T2x = 0.51;     %2nd mode period for longitudinal direction
T2y = 0.11;     %2nd mode period for transverse direction
% Use sPeriodX vector to determine indices
Xindex = 58;
Yindex = 28;

% Retrieve spectral data and put into PSDs matrix SdX
fid1 = fopen('./GM-Xcomp/input.txt','r');
for i = 1:nGM;
    filename = fgets(fid1);
    % -6 makes it such that name returned is free of extensions
    filename_c = filename(1:length(filename)-6);
    fprintf('GM in process = %s\n',filename_c);
    filename_d = strcat('./GM-Xcomp/SpectraX/',filename_c,'.SD');
    
    [fid2,message] = fopen(filename_d,'r');
    
    % READ TEXT LINES to bypass heading and get to data
    for k = 1:3;
        line = fgets(fid2);
    end
    dispX = fscanf(fid2,'%15e %15e ',192)*SF;
    cnt = 0;
    for j = 2:2:192;
        cnt = cnt+1;
        sPeriodX(cnt) = dispX(j-1);
        SdX(cnt,i) = dispX(j);         % Units in "response_TCL_NGA.m"
    end
end
medDispSpectraX = geomean(SdX');
fclose('all');

% Retrieve spectral data and put into PSDs matrix SdY
fid3 = fopen('./GM-Ycomp/input.txt','r');
for i = 1:nGM;
    filename = fgets(fid3);
    % -6 makes it such that name returned is free of extensions
    filename_c = filename(1:length(filename)-6);
    fprintf('GM in process = %s\n',filename_c);
    filename_d = strcat('./GM-Ycomp/SpectraY/',filename_c,'.SD');
    
    [fid4,message] = fopen(filename_d,'r');
    
    % READ TEXT LINES to bypass heading and get to data
    for k = 1:3;
        line = fgets(fid4);
    end
    dispY = fscanf(fid4,'%15e %15e ',192)*SF;
    cnt = 0;
    for j = 2:2:192;
        cnt = cnt+1;
        sPeriodY(cnt) = dispY(j-1);
        SdY(cnt,i) = dispY(j);         % Units in "response_TCL_NGA.m"
    end
end
medDispSpectraY = geomean(SdY');
fclose('all');
        
% Target displacements
Dhat2x = medDispSpectraX(Xindex);	% Same units as x
Dhat2y = medDispSpectraY(Yindex);	% Same units as x

% Scale factors
SF(1,1:nGM) = load('./GMs2/Scale_Factors.txt');
SF(2,1:nGM) = load('./GMs/Scale_Factors.txt');

% SF(:,19) = SF(:,19)*0.95;

% Compute normalized error E2
for i=1:nGM
    D2x = SdX(Xindex,i)*SF(1,i);
    D2y = SdY(Yindex,i)*SF(2,i);
    E2(i) = (abs(D2x-Dhat2x)+abs(D2y-Dhat2y))/(Dhat2x+Dhat2y);
%     E2(i) = (abs(D2x-Dhat2x))/(Dhat2x);
%     E2(i) = (abs(D2y-Dhat2y))/(Dhat2y);
end

% Rank records according to normalized error
[E2_sorted,GM_Ranking] = sort(E2,2,'ascend');

% Display ranking result
disp('Ground motions for set 4 are:');
GM_Ranking(1:7)
