%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% M-file to Solve nonliear SDOF oscillator response.
% Features:
%     - Multi-axial excitation
%     - P-Delta (global level)
%     - Material nonlinearity is resented by Ozdemir's model
%     - Spectral analysis for constant yield displacement
%
% Written by E.Kalkan
% Data Modified 13 Dec. 2006
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [Scale_Factor displ veloc foverm] = SDOF_OP(tgt,uy,gacc,GM,omegan,xi,tspan,td,Tn,dt);
gacc_org = gacc;
toll = 0.03; %Tolerance for convergency for Displacement
dSF = 1.2;
n = 1;
deltaSF = 0;
minposres = 10; minSF = 1.0; maxSF = 1.0;
minnegres = -10;
    tgt_duct = tgt/uy;
    fprintf('Target ductility = %5.2f\n',tgt_duct);
    fp1=fopen('GMotionScale.tcl','w');
    fprintf(fp1,'set GMfatt %5.3f',n); 
    fclose(fp1);
    dos('openSees test.tcl','-echo');
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    fname = strcat('M_',num2str(GM),'-acc.out');
    acc = load (fname) ;
    acc=acc(:,2); vel=cumtrapz(acc)*dt; displ_initial=cumtrapz(vel)*dt;
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    SF(1) = tgt_duct / (max(abs(displ_initial))/uy);
    if SF(1) < 0.1;
        SF(1) = 0.2;
    end
log=0;
for k=1:20; % k = number of iteration
    fprintf('\n Ite. No = %5.0f ',k);
    gacc = gacc_org*SF(k);    
    fp1=fopen('GMotionScale.tcl','w');
    fprintf(fp1,'set GMfatt %5.3f',SF(k)); 
    fclose(fp1);

    dos('openSees test.tcl');

    acc = load (fname) ;
    acc=acc(:,2); veloc=cumtrapz(acc)*dt; 
    displ=cumtrapz(veloc)*dt;
    
    fname2 = strcat('M_',num2str(GM),'-force.out');
    foverm = load (fname2); % Lateral resisting force over mass (inch/sec)     

% Compute & Check Ductility
    umax = max(abs(displ));
    duct = umax / uy;
    if duct > 20;
        SF(k) = SF(k)*0.8;
        gacc = gacc_org*SF(k);    
        fp1=fopen('GMotionScale.tcl','w');
        fprintf(fp1,'set GMfatt %5.3f',SF(k)); 
        fclose(fp1);
        dos('openSees test.tcl');
        acc = load (fname) ;
        acc=acc(:,2); veloc=cumtrapz(acc)*dt; 
        displ=cumtrapz(veloc)*dt;
        fname2 = strcat('M_',num2str(GM),'-force.out');
        foverm = load (fname2); % Lateral resisting force over mass (inch/sec)     
        umax = max(abs(displ));
        duct = umax / uy
    end
%--------------------------------------------------------------------------
% CONVERGENCE TEST : NEWTON AVERAGE ALGORITHM 
%--------------------------------------------------------------------------
    resid(k) = (umax-tgt)/tgt;

    if resid(k) > 0;
            if minposres > resid(k);
                minposres = resid(k);
                maxSF = SF(k);
                n = 1;
            end          
    elseif resid(k) < 0;
            if minnegres < resid(k);
                minnegres = resid(k);
                minSF = SF(k);
                n = 1;
            end
    end
    fprintf('SF=%5.2f, Dct=%5.2f, umax=%5.2f, res=%5.2f, minSF=%5.2f, maxSF=%5.2f, n=%5.0f, dSF=%5.2f',SF(k),duct,umax,resid(k),minSF,maxSF,n,deltaSF);
    
    if k > 1.0
       % if resid(k) == resid(k-1);
            %SF(k+1) = -(maxSF - minSF)*0.2+maxSF;
       %     dSF = 1.1;
        if minposres == 10;
                SF(k+1) = SF(k)*dSF;
        elseif minnegres == -10;
                SF(k+1) = SF(k)/dSF;
        else
            deltaSF = (maxSF - minSF)/10;    
            if abs(minnegres) < abs(minposres);
                 SF(k+1) = minSF+deltaSF*n;
            elseif abs(minnegres) > abs(minposres);
                SF(k+1) = maxSF-deltaSF*n;
            end  
            n = n+1;
        end

     elseif k == 1.0
            if minposres == 10;
                SF(k+1) = SF(k)*dSF;
            elseif minnegres == -10;
                SF(k+1) = SF(k)/dSF;
            else
                SF(k+1) = (maxSF + minSF)/2;
            end
    end
    
    if  (abs(resid(k)) <= toll)
        fprintf('\n OK !!!!!!!!!!!!!!!!!!!!!!'); 
        break        
    end
end
Scale_Factor = SF(k); 
% PUT DATA INTO OUTPUT FILE
        char1 = 'SDOF_';
        char2 = num2str(GM);        
        filename = strcat(char1,char2,'.out');
        fp3=fopen(filename,'w');
        fprintf(fp3,'\n Target Displacement = %5.2f',tgt);
        fprintf(fp3,'\n Target Period = %5.2f',Tn);
        fprintf(fp3,'\n ------------------------------------------');
        fprintf(fp3,'\n Yield displacement = %5.2f',uy);
        fprintf(fp3,'\n Maximum displacement = %5.2f',umax);
        fprintf(fp3,'\n Computed ductility = %5.2f',duct);
        fprintf(fp3,'\n Scale factor = %5.2f',SF(k));
        fprintf(fp3,'\n Number of iteration = %5.2f',k);
        log=1;
        fclose(fp3);
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% ITERATION END HERE
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
return







