%% Plotting bar graph of peak inelastic displacements from SDF NLRHA
% (Longitudinal Direction)
%
% Summary: 
% 1) This file assumes nonlinearSDOF_OpNoScale.m has been run
% 2) Using the OpenSEES output generated from latter script, the target
% deformation is determined
% 3) Bar graphs are created to show peak inelastic displacement from suite
% of records and compare with target deformations for MPS and MPS Exact
%
% Written by E.Kalkan
% Modified by Neal Simon Kwong (nealsimonkwong@berkeley.edu)
% Date Modified: Dec 2010

%% User input
clear all; close all; 

% Path locating NLRHA output (SDF sytem using OpenSEES)
fpath_OSoutput = 'F:\MPS\Skew Bridge\NLRHA\Sets_Exact\Target_Exact\GM-Xcomp\InSpecReg\M_';
fpath_Fig = 'F:\MPS\Skew Bridge\Figures\';
fname = 'Fig_25_SDFdispComparisonX';

convF = 2.54;       % Equals 2.54 if displacement in cm is desired, equals 1.0 if displacement in inches is desired
T = 0.81;           % Approx Fund Period of Equivalent SDF system
tgt = 8.74 ;        % Target X spectral displacement in inches obtained from empirical CR equation

nGM = 21;

% Controls vertical position of legend in figure
Yplacement = 1.525;

%% Extract OpenSEES output

tgt = tgt*convF ;  % Target X spectral displacement

for GM=1:nGM;
    clear displacement
    fname = strcat(fpath_OSoutput,num2str(GM),'-disp.out');
    displacement = load (fname);
    peakDisp(GM) = max(abs(displacement(:,2)))*convF;    % in cm
end

gmnDisp = geomean(peakDisp); % in appropriate units based on convF

%% Plot peak inelastic displacements
figure(1); orient tall; clf; 
set(gcf,'position',[300 283 300 300]);
set(gca,'TickLength',[.0025 .0025]);

% Plot individual peak inelastic displacements
bar(peakDisp,'EdgeColor','k','FaceColor',[0.5 0.5 0.5],'Barwidth',0.5); hold;

% Plot target displacements for both MPS and MPS Exact
X = [1 21]; Y = [tgt tgt]; Y2 = [gmnDisp gmnDisp];
line (X,Y,'Color','k','LineStyle','-','LineWidth',2.0);
line (X,Y2,'Color','r','LineStyle','--','LineWidth',2.0);
axis([1 21 0 90]); axis square;

%set(gca,'Ytick',[10:10:60])
%set(gca,'YTickLabel',{'10','20','30','40','50','60'},'fontsize',8);

if convF == 1.0
    ylabel('D_{1x}^I (inches)','FontSize',[9],'FontWeight','bold');
elseif convF == 2.54
    ylabel('D_{1x}^I (cm)','FontSize',[9],'FontWeight','bold');
else
    disp('Check units for target displacement!!!!');
end

xlabel('Ground Motion','FontSize',[9],'FontWeight','bold');

%set(gca,'Xtick',[0:2:22])
%set(gca,'XTickLabel',{'0','','4','','8','','12','','16','','20',''},'fontsize',8);

% Provide legend items
X1 = [2 5]; X2 = [3.5, 3.5];
Y1 = [5.5 5.5]*10*Yplacement; Y2 = [5.0, 5.0]*10*Yplacement; Y3 = [4.5 4.5]*10*Yplacement;
plot(X1,Y1,'-','Color','k','LineWidth',2.0);
text('pos',[X1(2)+0.5 Y1(2)],'str','C_R Equation','Color','k','FontSize',[9],'FontWeight','normal');
plot(X1,Y2,'--','Color','r','LineWidth',2.0);
text('pos',[X1(2)+0.5 Y2(2)],'str','Median','Color','k','FontSize',[9],'FontWeight','normal');
rectangle('Position',[2,43.5*Yplacement,3.,4.5],'FaceColor',[0.5 0.5 0.5],'LineWidth',0.5,'LineStyle','-');
text('pos',[X1(2)+0.5 Y3(2)],'str','i^t^h GM','Color','k','FontSize',[9],'FontWeight','normal');

% % Save figure
% savefile(fpath_Fig,fname); 
