%% ----------------------SUMMARY-------------------------------------------
% Function to estimate CR coefficient
% CR is used to estimate the inelastic deformation of SDF system:
% Ex: D1(inelastic) = CR*D1(elastic)
% Reference: Chopra, A. K. and Chintanapakdee, C. (2004)

%% ----------------------DEFINITIONS---------------------------------------
% Tn   = natural period of SDF system of interest (also T1)
% Tc   = period separating the acceleration and velocity-sensitive regions 
%        of the target spectrum
% R    = yield-strength reduction factor
% alfa = post-yield stiffness ratio
% LR   = limiting value of CR equation when Tn approaches 0

%% ----------------------FUNCTION------------------------------------------
function [CR] = chopra(Tn,Tc,R,alfa);

if alfa <= 0;
    LR = inf;
else
    LR = ( 1 / R ) * ( 1 + (R-1)/alfa );
end

a = 61;
b = 2.4; 
c = 1.5; 
d = 2.4;

CR = 1+ ( (LR-1)^-1 + (a/R^b + c)*(Tn/Tc)^d )^-1;

return