%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% M-file to display gravity deflected shapes for skew bridge model
%
% Written by N.Kwong (nealsimonkwong@berkeley.edu)
% Date Modified: 24 Nov 2010
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ----------------------DEFINITIONS---------------------------------------
% gravityDirectory  = specifies path to locate gravity analysis output 
% amp               = magnifies nodal movements to better display shape
% finalLoadStep     = identifies which row in data from OpenSEES to extract
% deflectedShape    = matrix containing x,y,z translations at all nodes

%% User Input
clear all; clc; close all;

gravityDirectory = 'J:\MPS\Skew Bridge\OpenSees_Skw\GravOutput';
cd(gravityDirectory)

amp = 75;  
finalLoadStep = 10;

%% Set up original geometry
geo_org = load('origGeo.txt');
% size(geo_org)

% Deck
x_org(1:81) = geo_org(1:81,2);
y_org(1:81) = geo_org(1:81,3);
z_org(1:81) = geo_org(1:81,4);

% North bent
x_org(82:90) = geo_org(82:90,2);
y_org(82:90) = geo_org(82:90,3);
z_org(82:90) = geo_org(82:90,4);

% South bent
x_org(91:99) = geo_org(91:99,2);
y_org(91:99) = geo_org(91:99,3);
z_org(91:99) = geo_org(91:99,4);

%% Extract gravity displaced shape
deflectedShape = zeros(3,99);

fileX = load('GravShapeX.out');
fileY = load('GravShapeY.out');
fileZ = load('GravShapeZ.out');

deflectedShape(1,:) = amp*fileX(finalLoadStep,:);
deflectedShape(2,:) = amp*fileY(finalLoadStep,:);
deflectedShape(3,:) = amp*fileZ(finalLoadStep,:);

%% Plot deflected shape due to gravity loading
set(gca,'FontSize',14);
% Plot undeformed shape first---------------------------------------------
% Deck
plot3(x_org(1:81),y_org(1:81),z_org(1:81),'ko-')
grid on; hold on;
% North bent
plot3(x_org(82:90),y_org(82:90),z_org(82:90),'ko-')
% South bent
plot3(x_org(91:99),y_org(91:99),z_org(91:99),'ko-')
% Rigid beam
plot3(x_org([90 99]),y_org([90 99]),z_org([90 99]),'ko-')

% Superimpose deflected shape---------------------------------------------
xdef = x_org + deflectedShape(1,:);
ydef = y_org + deflectedShape(2,:);
zdef = z_org + deflectedShape(3,:);

% Deck
hd = plot3(xdef(1:81),ydef(1:81),zdef(1:81),'Color',[0 0 1]);
% North bent
hnb = plot3(xdef(82:90),ydef(82:90),zdef(82:90),'Color',[0 0 1]);
% South bent
hsb = plot3(xdef(91:99),ydef(91:99),zdef(91:99),'Color',[0 0 1]);
% Rigid beam
hrb = plot3(xdef([90 99]),ydef([90 99]),zdef([90 99]),'Color',[0 0 1]);

set(hd,'LineWidth',5);
set(hnb,'LineWidth',5);
set(hsb,'LineWidth',5);
set(hrb,'LineWidth',5);
