%% ------------------------------------------------------------------------
% Plot Benchmark EDPs and Compute Simple Statistics (Transverse Direction)
%
% Summary: This script uses the workspace file post_process.mat to plot
% benchmark EDPs and determine the scatter among unscaled records.
% 
% Written by E. Kalkan
% Modified by: N.Kwong (nealsimonkwong@berkeley.edu)
% Date Modified: Nov 2010

%% ----------------------DEFINITIONS---------------------------------------
% numGM                 = number of records in benchmark set
% fpath_BM              = specifies location of workspace file for
%                         benchmark EDPs
% fpath                 = file path to place saved figures 
% fname                 = name for figures to be saved
% medRDR                = median drift ratio among all records (in %)
% medCol_Rot            = median column plastic rotation among all records
%                         (in rad)
% discrp_RDR            = discrepancy between drift ratio for ith GM and the median value 
% discrp_Col_Rot        = discrepancy between column plastic rotation for
%                         ith GM and the median value from the set
% dispersion_RDR        = standard deviation of drift ratios
% dispersion_Col_Rot    = standard deviation of column plastic rotations
% output                = collection of dispersions of interest

%% User Input
clear all; clc; close all; 

numGM = 21;

fpath_BM = 'J:\Skew Bridge\NLRHA\Benchmark\Skew_Unscaled\post_process.mat';
fpath = 'J:\Skew Bridge\Figures\';
fname = 'Fig_21_BenchmarkEDPs_Bar';

%% Extract Benchmark EDPs from workspace file and compute median values
load(fpath_BM);
medRDR = geomean(RDR')*100; medRDR = medRDR';
medCol_Rot = geomean(PlasticRot_Trans_Max');

%% Plot Benchmark EDPs along with median values
figure(1); orient tall; clf; 
set(gcf,'position',[300 283 650 300]);
set(gca,'TickLength',[.0025 .0025]);
subplot1(1,2,'Gap',[0.11 0.01]); 
    
subplot1(1);
    X = [0 numGM]; Y = [medRDR medRDR];    
    plot(X, Y,'--r','LineWidth',2.0);
    bar(NodalDisp_Trans_Max/h*100,'EdgeColor','k','FaceColor',[0.5 0.5 0.5],'Barwidth',0.6);
    plot(X, Y,'--r','LineWidth',2.0);
    legend('Median','i^t^h GM','Location','NW'); legend boxoff 
    axis([1 numGM 0 6]);
    ylabel('Deck Drift Ratio (%)','FontSize',[10],'FontWeight','bold'); 
    xlabel('Ground Motion','FontSize',[10],'FontWeight','bold'); 
%     set(gca,'Ytick',[0:2]);
    set(gca,'fontsize',9);axis square;
%     set(gca,'xtick',[0:1:numGM]);
    set(gca,'YTickLabel',{'0','','2','','4','','6'},'fontsize',9);    
    set(gca,'XTickLabel',{},'fontsize',9); 
subplot1(2);    
    set(gca,'fontsize',9);axis square;
    Y = [medCol_Rot medCol_Rot];
    bar(PlasticRot_Trans_Max,'EdgeColor','k','FaceColor',[0.5 0.5 0.5],'Barwidth',0.6);
    plot(X, Y,'--r','LineWidth',2.0);
    axis([1 numGM 0 0.06]);
    set(gca,'YTickLabel',{'0','','0.02','','0.04','','0.06'},'fontsize',9);
    ylabel('Column Plastic Rot. (rad)','FontSize',[10],'FontWeight','bold'); 
    xlabel('Ground Motion','FontSize',[10],'FontWeight','bold'); 
%     set(gca,'XTickLabel',{},'fontsize',9); 

% savefile(fpath,fname);

%% Compute ratios of median values and standard deviations
for i = 1:numGM
    discrp_RDR(i) = RDR(i)/medRDR*100;  
    discrp_Col_Rot(i) = PlasticRot_Trans_Max(i)/medCol_Rot;  
end

dispersion_RDR = std(discrp_RDR,0,2);
dispersion_Col_Rot = std(discrp_Col_Rot,0,2);

output = [dispersion_RDR 
    dispersion_Col_Rot];
open output
  