###############################################################################################
#Start Modeling the Lateral Pushover Loads in TRANSVERSE DIRECTION
pattern Plain 2 Linear {
	set eigFileIDx  [open $eigFolder/Mode_1x.out r]
	gets $eigFileIDx line
	set mode1x  [split $line]
	puts "size of mode1x  is: [llength $mode1x ]"	
	close $eigFileIDx

	set eigFileIDy  [open $eigFolder/Mode_1y.out r]
	gets $eigFileIDy  line
	set mode1y  [split $line]
	puts "size of mode1y  is: [llength $mode1y ]"	
	close $eigFileIDy
	
	set i 1
	foreach m $mList phix $mode1x phiy $mode1y {
		#  node	Fx	Fy	Fz 	  Mx	My  Mz
		set Hx  [expr $m*$phix ]
		set Hy  [expr $m*$phiy ]
		load $i $Hx $Hy 0.0 0.0 0.0 0.0 
		incr i 1
	}
} 	
puts "finished creating the lateral loads in direction of mode 1..."

#----------------------------------------------------------------------
#                                                   PUSHOVER ANALYSIS
#----------------------------------------------------------------------

puts "pushover analysis for TRANSVERSE direction starts"

# Put pushover output in same directory as eigen output 

#set recTag1 [recorder Node -file $eigFolder/MasterNodeDisp.out -node 39 -dof 1 2 disp]
set recTag1x [recorder Node -file $eigFolder/MasterNodeDisp_Long.out -node 39 -dof 1 disp]
set recTag1y [recorder Node -file $eigFolder/MasterNodeDisp_Trans.out -node 39 -dof 2 disp]

#set recTag2 [recorder Node -file $eigFolder/Reactions.out -node 100 101 102 103 -dof 1 2 reaction]
set recTag2x [recorder Node -file $eigFolder/Reactions_Long.out -node 100 101 102 103 -dof 1 reaction]
set recTag2y [recorder Node -file $eigFolder/Reactions_Trans.out -node 100 101 102 103 -dof 2 reaction]

set recTag3 [recorder Element -file $eigFolder/PlasticRot.out -ele 81 85 plasticDeformation]

set maxU 1.15
set dU [expr $maxU/100]
		
system BandGeneral
test NormDispIncr 1.0e-12 100
algorithm Newton

integrator DisplacementControl 39 2 $dU

analysis Static
set numSteps [expr int($maxU/$dU)]
analyze $numSteps

#remove recorder $recTag1
#remove recorder $recTag2

remove recorder $recTag1x
remove recorder $recTag1y
remove recorder $recTag2x
remove recorder $recTag2y
remove recorder $recTag3

# Compute first mode properties
set L1 0
set M1 0
foreach m $mList phix $mode1x phiy  $mode1y  {
	set L1 [expr $L1+($m*$phix )+($m*$phiy)]
	set M1 [expr $M1+($m*$phix *$phix )+($m*$phiy *$phiy )]
}

set Gamma1 [expr $L1/$M1]
set phiMasterNodex [lindex $mode1x  38]
set phiMasterNodey [lindex $mode1y  38]
set phiMasterNode [expr pow((pow($phiMasterNodex,2)+pow($phiMasterNodey,2)),0.5)]

set M1eff [expr $Gamma1*$L1]

puts "Modal participation factor for mode 1 is: $Gamma1"
puts "Modal displacement for master node is: $phiMasterNode"
puts "Effective modal mass for mode 1 is: $M1eff"

puts "Pushover Analysis is complete!!!"
