###############################################################################################
#Start Modeling the Lateral Pushover Loads in LONGITUDINAL DIRECTION
pattern Plain 2 Linear {
	set eigFileID [open eigOutput/Mode_1x.out r]
	gets $eigFileID line
	set mode1 [split $line]
	puts "size of mode1x is: [llength $mode1]"	
	close $eigFileID
	
	set i 1
	foreach m $mList phi $mode1 {
		#  node	Fx	Fy	Fz 	  Mx	My  Mz
		set H [expr $m*$phi]
		load $i $H 0.0 0.0 0.0 0.0 0.0 
		incr i 1
	}
} 
puts "finished creating the lateral loads for longitudinal direction..."

#----------------------------------------------------------------------
#                                                   PUSHOVER ANALYSIS
#----------------------------------------------------------------------

#wipeAnalysis

puts "pushover analysis for longitudinal direction starts"

# Put pushover output in same directory as eigen output
set filename eigOutput;   

set recTag1 [recorder Node -file $filename/MasterNodeDisp_Long.out -node 39 -dof 1 disp]
set recTag2 [recorder Node -file $filename/Reactions_Long.out -node 100 101 102 103 -dof 1 reaction]
set recTag3 [recorder Element -file $filename/PlasticRot.out -ele 81 85 plasticDeformation]

set maxU 1.5
set dU [expr $maxU/100]

#constraints Transformation
#numberer RCM
system BandGeneral
test NormDispIncr 1.0e-12 50
algorithm Newton

integrator DisplacementControl 39 1 $dU

analysis Static
set numSteps [expr int($maxU/$dU)]
analyze $numSteps

remove recorder $recTag1
remove recorder $recTag2
remove recorder $recTag3

# Compute first mode properties
set L1 0
set M1 0
foreach m $mList phi $mode1 {
	set L1 [expr $L1+($m*$phi)]
	set M1 [expr $M1+($m*$phi*$phi)]
}

set Gamma1 [expr $L1/$M1]
set phiMasterNode [lindex $mode1 38]
set M1eff [expr $Gamma1*$L1]

puts "Modal participation factor for mode 1 is: $Gamma1"
puts "Modal displacement for master node is: $phiMasterNode"
puts "Effective modal mass for mode 1 is: $M1eff"

puts "Pushover Analysis is complete!!!"
