# OpenSees -- Open System for Earthquake Engineering Simulation
# ----------------------
#  Painter Street Overcrossing
#------------------------------------------------------------------------
#                                                   STARTS
#                                                  ---------------------- 
wipe
model BasicBuilder -ndm 3 -ndf 6
#-----------------------------------------------------------------------
#                                                   PARAMETERS
#                                                  ---------------------
#-----------------------------------
# CORRECTION COEFFICIENTS
#-----------------------------------
#-------Trial of any combination------------------
set coef_bc   1.0 ;      # for B.C.
set c_Damp    0.0 ;      # for Damping coefficient
set c_Bent    1.0;       # for upper part of bent geometry
#------------------------------------------------------------------------
#                                                   ELEMENT PROPERTIES
#                                                  ---------------------- 
#-----------------------------------
# MATERIAL & SECTION PROPERTIES
#-----------------------------------
set E_conc      417708; # from Zhang & Makris
set EEbent      $E_conc
set EEdeck      $E_conc;    # Youngs modulus
set EEcap       481320;     # not used in this model
#----DECK-----------
set Edeck      $EEdeck;              # Youngs modulus
set Adeck      89.2344;            # Area 
set Gdeck     [expr $Edeck/2.4];   # Shear modulus
set Jdeck     1349.2459;            # torsional coeff
set Iydeck    421.7017;            # local y-axis
set Izdeck    17831.428;            # local z-axis
#----BENT-lower part------------
set Ebent      $EEbent
set Abent      20.6855
set Gbent      [expr $Ebent/2.4]
set Jbent      64.78 
set Iybent     34.128
set Izbent     34.128
#----BENT-upper part------------
set Abent_u    [expr 34.7051*pow($c_Bent,2)]
set Gbent_u    [expr $Ebent/2.4]
set Jbent_u    [expr 182.3594*pow($c_Bent,4)] 
set Iybent_u   [expr 96.0650*pow($c_Bent,4)]
set Izbent_u   [expr 96.0650*pow($c_Bent,4)]
#----CAP BEAM------------
set Ecap      $EEcap
set Acap      31.167
set Gcap      [expr $Ecap/2.4]
set Jcap      136.312
set Iycap     83.399
set Izcap     78.566
#------------------------------------------------------------------------
#                                                   SPRING STIFFNESS
#                                                  ----------------------
#----SPRING STIFFNESS (ABUTMENT)---------
set sDX_A     [expr  5328.72*$coef_bc]; # global-x(KIPS/FT)
set sDY_A     [expr  5328.72*$coef_bc]; # global-y(KIPS/FT)
set sDZ_A     [expr 22743.24*$coef_bc]; # global-z(KIPS/FT)
#----SPRING STIFFNESS (COLUMN)---------
set sDX_C     [expr 21988.43*$coef_bc]; # global-x
set sDY_C     [expr 21988.43*$coef_bc]; # global-y
set sDZ_C     [expr 67266.79*$coef_bc]; # global-z
set sRX_C     [expr 261013.23*$coef_bc];  # global-x
set sRY_C     [expr 261013.23*$coef_bc];  # global-y
set sRZ_C     [expr 3873908.24*$coef_bc]; # global-z
#------------------------------------------------------------------------
#                                                   DAMPING COEFFICIENT
#                                                  ----------------------
#-----Damping Coefficient (Abutment)------------- 
set alpha  1
#set CX_A   [expr  308.25*$c_Damp];        # global-x (kips-s/ft)
#set CY_A   [expr  308.25*$c_Damp];        # global-y  
#set CZ_A   [expr  893.31*$c_Damp];        # global-z 
#-----Damping Coefficient (Column)-------------  
#set CX_C   [expr 342.5*$c_Damp];       # global-x  
#set CY_C   [expr 342.5*$c_Damp];       # global-y (kips-s/ft) 
#set CZ_C   [expr 1370*$c_Damp];        # global-Z 
#-----------------------------------------------------------------------
#                                                   MATERIAL -ABUTMENT
#                                                  ---------------------
# uniaxialMaterial    Elastic   matID      E    
uniaxialMaterial    Elastic       1      $sDX_A;    # global-X
uniaxialMaterial    Elastic       2      $sDY_A;    # global-y
uniaxialMaterial    Elastic       3      $sDZ_A;    # global-z
#----Damping Material Assignment---------
#uniaxialMaterial   Viscous        11  $CX_A   $alpha;  # global x
#uniaxialMaterial   Viscous        12  $CY_A   $alpha;  # global y
#uniaxialMaterial   Viscous        13  $CZ_A   $alpha;  # global z
#----Parallel Material Assignment (Abutment)---------
#uniaxialMaterial   Parallel  51  11  1;    # global x
#uniaxialMaterial   Parallel  52  12  2;    # global y
#uniaxialMaterial   Parallel  53  13  3;    # global z
#-----------------------------------------------------------------------
#                                                   MATERIAL -column
#                                                  ---------------------
# translational spring
uniaxialMaterial    Elastic       21      $sDX_C; # global-x
uniaxialMaterial    Elastic       22      $sDY_C; # global-y
uniaxialMaterial    Elastic       23      $sDZ_C; # global-z
# rotational spring
uniaxialMaterial    Elastic       64      $sRX_C ; # global-x
uniaxialMaterial    Elastic       65      $sRY_C ; # global-y
uniaxialMaterial    Elastic       66      $sRZ_C ; # global-z
#----Damping Material Assignment (Column)---------
#uniaxialMaterial   Viscous        31      $CX_C   $alpha;  # global x
#uniaxialMaterial   Viscous        32      $CY_C   $alpha;  # global y
#uniaxialMaterial   Viscous        33      $CZ_C   $alpha;  # global z
#----Parallel Material Assignment (Column)---------
#uniaxialMaterial   Parallel  61  21  31;    # global x
#uniaxialMaterial   Parallel  62  22  32;    # global y
#uniaxialMaterial   Parallel  63  23  33;    # global z
#-----------------------------------------------------------------------
#                                                   NODES
#                                                  ---------------------
node     1               0               0               0
node     2            3.25               0               0
node     3             6.5               0               0
node     4         9.79512               0               0
node     5         13.0902               0               0
node     6         16.3854               0               0
node     7         19.6805               0               0
node     8         22.9756               0               0
node     9         26.2707               0               0
node    10         29.5659               0               0
node    11          32.861               0               0
node    12         36.1561               0               0
node    13         39.4512               0               0
node    14         42.7464               0               0
node    15         46.0415               0               0
node    16         49.3366               0               0
node    17         52.6317               0               0
node    18         55.9269               0               0
node    19          59.222               0               0
node    20         62.5171               0               0
node    21         65.8075               0               0
node    22         69.0978               0               0
node    23         72.3882               0               0
node    24         75.6786               0               0
node    25          78.969               0               0
node    26         82.2593               0               0
node    27         85.5497               0               0
node    28         88.8401               0               0
node    29         92.1305               0               0
node    30         95.4208               0               0
node    31         98.7112               0               0
node    32         102.002               0               0
node    33         105.292               0               0
node    34         108.582               0               0
node    35         111.873               0               0
node    36         115.163               0               0
node    37         118.453               0               0
node    38         121.744               0               0
node    39         125.034               0               0
node    40         128.368               0               0
node    41         131.702               0               0
node    42         135.036               0               0
node    43          138.37               0               0
node    44         141.704               0               0
node    45         145.038               0               0
node    46         148.372               0               0
node    47         151.706               0               0
node    48          155.04               0               0
node    49         158.374               0               0
node    50         161.708               0               0
node    51         165.042               0               0
node    52         168.376               0               0
node    53          171.71               0               0
node    54         175.044               0               0
node    55         178.378               0               0
node    56         181.712               0               0
node    57         185.046               0               0
node    58          188.38               0               0
node    59         191.714               0               0
node    60         195.048               0               0
node    61         198.391               0               0
node    62         201.734               0               0
node    63         205.077               0               0
node    64          208.42               0               0
node    65         211.763               0               0
node    66         215.105               0               0
node    67         218.448               0               0
node    68         221.791               0               0
node    69         225.134               0               0
node    70         228.477               0               0
node    71          231.82               0               0
node    72         235.163               0               0
node    73         238.505               0               0
node    74         241.848               0               0
node    75         245.191               0               0
node    76         248.534               0               0
node    77         251.877               0               0
node    78          255.22               0               0
node    79         258.563               0               0
node    80         261.813               0               0
node    81         265.063               0               0
#----BENT (NORTH)----------
node    82         113.097         14.7817        -26.8333
node    83         113.097         14.7817        -23.4792
node    84         113.097         14.7817         -20.125
node    85         113.097         14.7817        -16.7708
node    86         113.097         14.7817        -13.4167
node    87         113.097         14.7817        -10.0625
node    88         113.097         14.7817        -6.70833
node    89         113.097         14.7817        -3.35417
node    90         113.097         14.7817               0
#----BENT (SOUTH)----------
node    91         136.972        -14.7817        -26.8333
node    92         136.972        -14.7817        -23.4792
node    93         136.972        -14.7817         -20.125
node    94         136.972        -14.7817        -16.7708
node    95         136.972        -14.7817        -13.4167
node    96         136.972        -14.7817        -10.0625
node    97         136.972        -14.7817        -6.70833
node    98         136.972        -14.7817        -3.35417
node    99         136.972        -14.7817               0
#-------------
# Begining of Bridge : node 1
# End of             : node 81
# North Bent         : node 82 -node 90
# South Bent         : node 91 -node 99
#-----------------------------------------------------------------------
#                                             GEOMETRIC TRANSFORMATION
#                                              -------------------------
#geomTransf Linear $tag   vecxzX  vecxzY   vecxzZ
geomTransf Linear    1       0         0       -1 ; # DECK & CAPBEAM
geomTransf Linear    2      -1         0        0 ; # BENT
#-----------------------------------------------------------------------
#                                                   ELEMENTS
#                                                  ---------------------
#-----DECK-------
for {set i 1} {$i <= 80} {incr i 1} {
      set iNode [expr $i]
      set jNode [expr $i+1]
	element elasticBeamColumn $i $iNode $jNode $Adeck $Edeck $Gdeck $Jdeck $Iydeck $Izdeck  1
}
#-----BENT (NORTH)------------
for {set i 81} {$i<=85} {incr i 1} {
      set iNode [expr $i+1]
      set jNode [expr $i+2]
	element elasticBeamColumn $i $iNode $jNode $Abent  $Ebent $Gbent $Jbent $Iybent $Izbent  2
}
for {set i 86} {$i<=88} {incr i 1} {
      set iNode [expr $i+1]
      set jNode [expr $i+2]
	element elasticBeamColumn $i $iNode $jNode $Abent_u  $Ebent $Gbent_u $Jbent_u $Iybent_u $Izbent_u  2
}
#-----BENT (SOUTN)------------
for {set i 89} {$i<=93} {incr i 1} {
      set iNode [expr $i+2]
      set jNode [expr $i+3]
 	element elasticBeamColumn $i $iNode $jNode $Abent  $Ebent $Gbent $Jbent $Iybent $Izbent  2
}
for {set i 94} {$i<=96} {incr i 1} {
      set iNode [expr $i+2]
      set jNode [expr $i+3]
 	element elasticBeamColumn $i $iNode $jNode $Abent_u  $Ebent $Gbent_u $Jbent_u $Iybent_u $Izbent_u  2
}
#-----CAP BEAM------------
# rigidLink $type   $masterNode  $slaveNode
rigidLink  beam 39  99
rigidLink  beam 39  90
#-----------------------------------------------------------------------
#                                                   MASS
#                                                  ---------------------
# -----------------------------------
# DEFINE MASS
# -----------------------------------
set MDen   0.0046627;     # mass density : kips/ft^3/(ft/sec^2)
set g      386;           # gravitational acce. 
set L_ele_1   3.25;            # Ele 1 to 2
set L_ele_2   3.295;           # Ele 3 to 19
set L_ele_3   3.29;            # Ele 20 to 38
set L_ele_4   3.334;           # Ele 39 to 78
set L_Bent    3.3542;          # bent ele length
set m1      [expr $MDen*$Adeck*$L_ele_1/2];   # mass per node span 1
set m2      [expr $m1*2];
set mDeck_2 [expr $MDen*$Adeck*$L_ele_2/2];
set m3      [expr $m1 + $mDeck_2]
set mDeck_3 [expr $MDen*$Adeck*$L_ele_3/2];
set mDeck_4 [expr $MDen*$Adeck*$L_ele_4/2];
set mBent   [expr $MDen*$Abent*$L_Bent/2];   # mass per node span 1
set mCap    [expr $MDen*$Acap*19/2];        # 19-ele length
#---DECK-----------
#mass  tag  Mx       My       Mz        Rx     Ry    Rz  
mass    1   $m1      $m1      $m1       0.0    0.0   0.0
mass    2   $m2      $m2      $m2       0.0    0.0   0.0
mass    3   $m3      $m3      $m3       0.0    0.0   0.0
for {set i 4} {$i <= 19} {incr i 1} {
	set m [expr $mDeck_2*2]
mass    $i   $m      $m       $m        0.0     0.0   0.0
}
set m20 [expr $mDeck_2 + $mDeck_3]
mass  20   $m20   $m20    $m20   0.0     0.0   0.0
for {set i 21} {$i <= 38} {incr i 1} {
 	set m [expr $mDeck_3*2]
mass    $i   $m      $m       $m        0.0     0.0   0.0
}
set m39 [expr ($mDeck_3+$mDeck_4+$mCap*2)]
mass    39  $m39  $m39   $m39  0.0  0.0   0.0
#--------
for {set i 40} {$i <= 78} {incr i 1} {
 	set m [expr $mDeck_4*2]
mass   $i   $m       $m       $m        0.0     0.0   0.0
}
set m79 [expr $mDeck_4 + $m1]
set m80 [expr $m1*2]
set m81 [expr $m1]
#--------
mass    79  $m79  $m79  $m79     0.0    0.0   0.0
mass    80  $m80  $m80  $m80     0.0    0.0   0.0
mass    81  $m81  $m81  $m81     0.0    0.0   0.0
#---BENT (NORTH)---------
mass    82  $mBent  $mBent  $mBent     0.0    0.0   0.0
for {set i 83} {$i<=89} {incr i 1} {
	set m [expr $mBent*2]
	mass $i   $m   $m   $m  0.0  0.0  0.0
}
set    m90  [expr $mBent+$mCap]
mass    90  $m90  $m90  $m90     0.0    0.0   0.0
#---BENT (SOUTH)---------
mass    91 $mBent  $mBent  $mBent     0.0    0.0   0.0
for {set i 92} {$i<=98} {incr i 1} {
 	set m [expr $mBent*2]
	mass $i   $m   $m   $m  0.0  0.0  0.0
}
set    m99  [expr $mBent+$mCap]
mass    99  $m99  $m99  $m99    0.0    0.0   0.0
#-----------------------------------------------------------------------
#                                                   BOUNDARY CONDTIONNS
#                                                  ---------------------
#-------ABUTMENT----------------
# nodes for  zero length
node    100              0               0               0; # WEST
node    101         265.063              0               0; # EAST
fix    100    1 1 1 1 1 1;    # WEST ABUTMENT
fix    101    1 1 1 1 1 1;    # EAST ABUTMENT
#----------
# West Abut
element zeroLength    97    100       1   -mat 1 2 3 -dir 1 2 3; # WEST ABUT.
equalDOF                    100       1    4  6;         # 5-free rotation along y-axis 
#----------
# East Abut
element zeroLength   98     81     101    -mat 1 2 3 -dir 1 2 3; # EAST ABUT.
equalDOF       101     81    4  6;         # 5-free rotation along y-axis  
#-------BENT----------------
node   102         113.097         14.7817        -26.8333
node   103         136.972        -14.7817        -26.8333
fix    102    1 1 1 1 1 1;    # END OF NORTH BENT
fix    103    1 1 1 1 1 1;    # END OF SOUTH BENT
# Column
element zeroLength    99   102  82   -mat 21 22 23 64 65 66 -dir 1 2 3 4 5 6; # global direction
element zeroLength    100  103  91   -mat 21 22 23 64 65 66 -dir 1 2 3 4 5 6;
#-----------------------------------------------------------------------
#                                                   RAYLEIGH DAMPING
#                                                  ---------------------
# set rayleigh damping factors
#rayleigh  $alphaM   $betaKcur  $betaKinit   $betaKlastcomm
rayleigh   0.8122     0.0        0.0     0.0028  ; # zeta=5
#-----------------------------------------------------------------------
#                                                   DYNAMIC LOAD
#                                                  ---------------------
set DT   0.02 ;  # TIME STEP
set gTran    0.0328 ; # INPUT MOTION : gal(cm/sec/sec)-->UNIT: ft/sec^2
set  Accel "Path -filePath ch_03txt.txt -dt $DT -factor $gTran"
# Define the excitation using the Tabas ground motion records
#                         tag   dir         accel series args
pattern UniformExcitation  2      2         -accel      $Accel
#-----------------------------------------------------------------------
#                                                   ANALYSIS GENERATION
#                                                  ---------------------
wipeAnalysis
eigen frequency 10
#-----------------------------------------------------------------------
#                                                   NATURAL FREQUENCY
#                                                  ---------------------
set PI 3.1415926
set lambdax [eigen 10]
set outFileID [open freq.out w];    # y-direction : Transverse
for {set i 1} {$i <= 10} {incr i 1} {
	set lambda [lindex $lambdax [expr $i-1]]
	set omega [expr pow($lambda,0.5)]
	set Tperiod [expr 2*$PI/$omega]
	set natfreq [expr 1/$Tperiod]
	set Freq($i) $natfreq
}
puts "T1 is [expr 1/$Freq(1)] sec"
puts "T2 is [expr 1/$Freq(2)] sec"

# --------------------------------
# Analysis Options-to write modeshape this part is needed
# ---------------------------------
system BandGeneral
## Create the constraint handler, the transformation method
constraints Transformation
## Create the DOF numberer, the reverse Cuthill-McKee algorithm
numberer RCM
## Create the convergence test, the norm of the residual with a tolerance of 
## 1e-12 and a max number of iterations of 10
##                  tolerance maxIter displayCode
test NormDispIncr 1.0e-12      30       0
## Create the solution algorithm, a Newton-Raphson algorithm
algorithm Newton
## Create the integration scheme, the LoadControl scheme using steps of 0.1 
integrator LoadControl 0.1
## Create the analysis object
analysis Static
analyze 1
# ------------------------------
# Finally perform the analysis
# ------------------------------
set oFile_5 "zhang_5per.mat"
recorder  Node -file $oFile_5     -time -node 39 -dof 2 accel
## --------------------
# Perform the analysis
# --------------------
# ---------------------------------------------------------
# Start of modifications to analysis for transient analysis
# ---------------------------------------------------------
## Delete the old analysis and all its component objects
wipeAnalysis
test EnergyIncr 1.0e-8   20         3
algorithm  Newton
system SparseGeneral -piv
#integrator Newmark  0.5  0.25
integrator Newmark  0.5  0.25 
numberer RCM
constraints Transformation
# create  the analysis object
analysis  Transient
#type  "Starting Tansient Analysis .. hang on"
#       numSteps   dt
analyze     3000    0.02
