function PDFs(PGA,PGA_NGA)
%PDFS    Create plot of datasets and fits
%   PDFS(PGA,PGA_NGA)
%   Creates a plot, similar to the plot in the main distribution fitting
%   window, using the data that you provide as input.  You can
%   apply this function to the same data you used with dfittool
%   or with different data.  You may want to edit the function to
%   customize the code and this help message.
%
%   Number of datasets:  2
%   Number of fits:  2

% This function was automatically generated on 27-Oct-2009 17:48:13
 
% Data from dataset "Atlas":
%    Y = PGA
 
% Data from dataset "Extended NGA":
%    Y = PGA_NGA
 
% Force all inputs to be column vectors
PGA = PGA(:);
PGA_NGA = PGA_NGA(:);

% Set up figure to receive datasets and fits
f_ = clf;
figure(f_);
set(f_,'Units','Pixels','Position',[1 31 1280 633.45]);
legh_ = []; legt_ = {};   % handles and text for legend
ax_ = newplot;
set(ax_,'Box','on');
hold on;

% --- Plot data originally in dataset "Atlas"
t_ = ~isnan(PGA);
Data_ = PGA(t_);
[F_,X_] = ecdf(Data_,'Function','cdf'...
              );  % compute empirical cdf
Bin_.rule = 1;
[C_,E_] = dfswitchyard('dfhistbins',Data_,[],[],Bin_,F_,X_);
[N_,C_] = ecdfhist(F_,X_,'edges',E_); % empirical pdf from cdf
h_ = bar(C_,N_,'hist');
set(h_,'FaceColor','none','EdgeColor',[1 0 0],...
       'LineStyle','-', 'LineWidth',1);
xlabel('Data');
ylabel('Density')
legh_(end+1) = h_;
legt_{end+1} = 'Atlas';
% --- Plot data originally in dataset "Extended NGA"
t_ = ~isnan(PGA_NGA);
Data_ = PGA_NGA(t_);
[F_,X_] = ecdf(Data_,'Function','cdf'...
              );  % compute empirical cdf
Bin_.rule = 1;
[C_,E_] = dfswitchyard('dfhistbins',Data_,[],[],Bin_,F_,X_);
[N_,C_] = ecdfhist(F_,X_,'edges',E_); % empirical pdf from cdf
h_ = bar(C_,N_,'hist');
set(h_,'FaceColor','none','EdgeColor',[0 0 1],...
       'LineStyle','--', 'LineWidth',1);
xlabel('Data');
ylabel('Density')
legh_(end+1) = h_;
legt_{end+1} = 'Extended NGA';

% Nudge axis limits beyond data limits
xlim_ = get(ax_,'XLim');
if all(isfinite(xlim_))
   xlim_ = xlim_ + [-1 1] * 0.01 * diff(xlim_);
   set(ax_,'XLim',xlim_)
end

x_ = linspace(xlim_(1),xlim_(2),100);

% --- Create fit "Fit: Atlas"

% Fit this distribution to get parameter values
t_ = ~isnan(PGA);
Data_ = PGA(t_);
% To use parameter estimates from the original fit:
%     p_ = [ -4.019174800082, 1.415086109881];
pargs_ = cell(1,2);
[pargs_{:}] = normfit(Data_, 0.05);
p_ = [pargs_{:}];
y_ = normpdf(x_,p_(1), p_(2));
h_ = plot(x_,y_,'Color',[1 0 0],...
          'LineStyle','-', 'LineWidth',3,...
          'Marker','none', 'MarkerSize',6);
legh_(end+1) = h_;
legt_{end+1} = 'Fit: Atlas';

% --- Create fit "Fit: Extended NGA"

% Fit this distribution to get parameter values
t_ = ~isnan(PGA_NGA);
Data_ = PGA_NGA(t_);
% To use parameter estimates from the original fit:
%     p_ = [ -3.049249612569, 1.236424212288];
pargs_ = cell(1,2);
[pargs_{:}] = normfit(Data_, 0.05);
p_ = [pargs_{:}];
y_ = normpdf(x_,p_(1), p_(2));
h_ = plot(x_,y_,'Color',[0 0 1],...
          'LineStyle','--', 'LineWidth',3,...
          'Marker','none', 'MarkerSize',6);
legh_(end+1) = h_;
legt_{end+1} = 'Fit: Extended NGA';

hold off;
leginfo_ = {'Orientation', 'vertical', 'FontName', 'Arial', 'FontSize', 12, 'Location', 'NorthEast'}; 
h_ = legend(ax_,legh_,legt_,leginfo_{:});  % create legend
set(h_,'Interpreter','none');
