%% Script for plotting distribution of EDPs
% Simon Kwong

%% User Input--------------------------------------------------------------
clear all; clc; close all;

fpath_BM = 'E:\MPS\Skew Bridge\NLRHA\Benchmark\Skew_Unscaled\post_process.mat';
fpath_MPS = 'E:\MPS\Skew Bridge\NLRHA\Sets_Exact\';

%% Extract benchmark EDP values for comparison
load(fpath_BM);
dir(1).target.medRDR = geomean(RDR_Long')*100;
dir(1).target.medCol_Rot = geomean(PlasticRot_Long_Max');
dir(2).target.medRDR = geomean(RDR')*100;
dir(2).target.medCol_Rot = geomean(PlasticRot_Trans_Max');

%% Extract all MPS EDP values
for setNum = 1:3
    filename = strcat(fpath_MPS,'Set-',num2str(setNum),'\Skew_Unscaled\post_process.mat');
    load (filename);
    % Drift ratios in percentages
    dir(1).DR(7*(setNum-1)+1:7*setNum) = RDR_Long.*100;
    dir(1).Prot(7*(setNum-1)+1:7*setNum) = PlasticRot_Long_Max;
    dir(2).DR(7*(setNum-1)+1:7*setNum) = RDR.*100;
    dir(2).Prot(7*(setNum-1)+1:7*setNum) = PlasticRot_Trans_Max;
end

%% Create sets (with size 7) of EDP data
numSets = nchoosek(3*7,7);
dir(1).comb.DR = nchoosek(dir(1).DR,7);
% dir(1).comb.DR = combnk(dir(1).DR,7);
dir(1).comb.Prot = nchoosek(dir(1).Prot,7);
dir(2).comb.DR = nchoosek(dir(2).DR,7);
dir(2).comb.Prot = nchoosek(dir(2).Prot,7);

% Identify sets
setID = 1:21;
setID_comb = nchoosek(setID,7);
for ii = 1:numSets
    if setID_comb(ii,:) == [1:7]
        dir(1).sets.DR(1,:) = dir(1).comb.DR(ii,:);
        dir(1).sets.Prot(1,:) = dir(1).comb.Prot(ii,:);
        dir(2).sets.DR(1,:) = dir(2).comb.DR(ii,:);
        dir(2).sets.Prot(1,:) = dir(2).comb.Prot(ii,:);
    elseif setID_comb(ii,:) == [8:14]
        dir(1).sets.DR(2,:) = dir(1).comb.DR(ii,:);
        dir(1).sets.Prot(2,:) = dir(1).comb.Prot(ii,:);
        dir(2).sets.DR(2,:) = dir(2).comb.DR(ii,:);
        dir(2).sets.Prot(2,:) = dir(2).comb.Prot(ii,:);
    elseif setID_comb(ii,:) == [15:21]
        dir(1).sets.DR(3,:) = dir(1).comb.DR(ii,:);   
        dir(1).sets.Prot(3,:) = dir(1).comb.Prot(ii,:);
        dir(2).sets.DR(3,:) = dir(2).comb.DR(ii,:);
        dir(2).sets.Prot(3,:) = dir(2).comb.Prot(ii,:);
    end
end

dir(1).check.DR = geomean(dir(1).sets.DR')./dir(1).target.medRDR;
dir(1).check.Prot = geomean(dir(1).sets.Prot')./dir(1).target.medCol_Rot;
dir(2).check.DR = geomean(dir(2).sets.DR')./dir(2).target.medRDR;
dir(2).check.Prot = geomean(dir(2).sets.Prot')./dir(2).target.medCol_Rot;

%% Compute median within each set and store in vector
dir(1).med.DR = geomean(dir(1).comb.DR');
% Divide drift ratios by target value
dir(1).med.DR = dir(1).med.DR./dir(1).target.medRDR;

dir(1).med.Prot = geomean(dir(1).comb.Prot');
% Divide plastic rotations by target value
dir(1).med.Prot = dir(1).med.Prot./dir(1).target.medCol_Rot;

dir(2).med.DR = geomean(dir(2).comb.DR');
% Divide drift ratios by target value
dir(2).med.DR = dir(2).med.DR./dir(2).target.medRDR;

dir(2).med.Prot = geomean(dir(2).comb.Prot');
% Divide plastic rotations by target value
dir(2).med.Prot = dir(2).med.Prot./dir(2).target.medCol_Rot;

%% Determine some statistics on EDP ratios
dir(1).med_normal.DR = median(dir(1).med.DR);
dir(1).std_normal.DR = std(dir(1).med.DR);
dir(1).CI_normal.DR = [dir(1).med_normal.DR-2*dir(1).std_normal.DR, dir(1).med_normal.DR+2*dir(1).std_normal.DR];

dir(1).med_normal.Prot = median(dir(1).med.Prot);
dir(1).std_normal.Prot = std(dir(1).med.Prot);
dir(1).CI_normal.Prot = [dir(1).med_normal.Prot-2*dir(1).std_normal.Prot, dir(1).med_normal.Prot+2*dir(1).std_normal.Prot];

dir(2).med_normal.DR = median(dir(2).med.DR);
dir(2).std_normal.DR = std(dir(2).med.DR);
dir(2).CI_normal.DR = [dir(2).med_normal.DR-2*dir(2).std_normal.DR, dir(2).med_normal.DR+2*dir(2).std_normal.DR];

dir(2).med_normal.Prot = median(dir(2).med.Prot);
dir(2).std_normal.Prot = std(dir(2).med.Prot);
dir(2).CI_normal.Prot = [dir(2).med_normal.Prot-2*dir(2).std_normal.Prot, dir(2).med_normal.Prot+2*dir(2).std_normal.Prot];

summary(1,:) = [dir(2).med_normal.DR dir(2).std_normal.DR];
summary(2,:) = [dir(2).med_normal.Prot dir(2).std_normal.Prot];
summary(3,:) = [dir(1).med_normal.DR dir(1).std_normal.DR];
summary(4,:) = [dir(1).med_normal.Prot dir(1).std_normal.Prot];
open summary

%% Plot
[counts binLoc] = hist(dir(1).med.DR,100);

figure;
set(gcf,'units','inches','Position',[1 1 12 8]);

colorList = {'r' 'g' 'b'};

subplot(2,2,1)
set(gca,'Fontsize',12,'Fontname','Times')

hist(dir(1).med.DR,100);
h = findobj(gca,'Type','patch');
set(h,'FaceColor',[0 1 1])
hold on

for ii = 1:length(dir(1).check.DR)
    plot([dir(1).check.DR(ii) dir(1).check.DR(ii)],[0 4000],'Color',colorList{ii},'Linewidth',1.5,'Linestyle','--');
end

xlabel('\bfEDP ratios, Deck drift (Long.)')
ylabel('\bfNumber of occurrences')
set(gca,'ytick',0:1000:4000);
text(1.9,4350,'\bfDistribution of EDP ratios for Skew Bridge, MPS-"Exact"','Fontsize',12,'horizontalalignment','center');

subplot(2,2,2)
set(gca,'Fontsize',12,'Fontname','Times')

for ii = 1:length(dir(1).check.Prot)
    plot([dir(1).check.Prot(ii) dir(1).check.Prot(ii)],[0 4000],'Color',colorList{ii},'Linewidth',1.5,'Linestyle','--');
    hold on
end
legend('Set 1','Set 2','Set 3');

hist(dir(1).med.Prot,100);
h = findobj(gca,'Type','patch');
set(h,'FaceColor',[0 1 1])

% Redraw lines
for ii = 1:length(dir(1).check.Prot)
    plot([dir(1).check.Prot(ii) dir(1).check.Prot(ii)],[0 4000],'Color',colorList{ii},'Linewidth',1.5,'Linestyle','--');
end

xlabel('\bfEDP ratios, Plastic Rotation (Long.)')
ylabel('\bfNumber of occurrences')
set(gca,'ytick',0:1000:4000);

subplot(2,2,3)
set(gca,'Fontsize',12,'Fontname','Times')
hist(dir(2).med.DR,100);
h = findobj(gca,'Type','patch');
set(h,'FaceColor',[0 1 1])

hold on
for ii = 1:length(dir(2).check.DR)
    plot([dir(2).check.DR(ii) dir(2).check.DR(ii)],[0 4000],'Color',colorList{ii},'Linewidth',1.5,'Linestyle','--');
end

xlabel('\bfEDP ratios, Deck drift (Trans.)')
ylabel('\bfNumber of occurrences')
set(gca,'ytick',0:1000:4000);

subplot(2,2,4)
set(gca,'Fontsize',12,'Fontname','Times')

hist(dir(2).med.Prot,100);
h = findobj(gca,'Type','patch');
set(h,'FaceColor',[0 1 1])

hold on
for ii = 1:length(dir(2).check.Prot)
    plot([dir(2).check.Prot(ii) dir(2).check.Prot(ii)],[0 4000],'Color',colorList{ii},'Linewidth',1.5,'Linestyle','--');
end

xlabel('\bfEDP ratios, Plastic Rotation (Trans.)')
ylabel('\bfNumber of occurrences')
set(gca,'ytick',0:1000:4000);

% savefile2(cd,'.\Distribution_EDPratio_Skew_MPSExact');