#----------------------------------------------------------------------
#                                                 COLUMN FIBER SECTIONS
#                                                  --------------------
# All units in feet, see assignMaterial.tcl for material tags

#----------------------------------------------------------------------
# LOWER BENT COLUMN SECTION                                                 
#----------------------------------------------------------------------
set totalDia 5.0; 				# Column Diameter
set clearCover [expr 3.125/12.0];	# Column cover to reinforcing steel NA.
set numBars 36;				# number of uniformly-distributed longitudinal-reinforcement bars
set barArea [expr 1.56/144.0];		# area of longitudinal-reinforcement bars
set SecTag 11;				# set tag for lower column section

# Generate a circular reinforced concrete section
# with one layer of steel evenly distributed around the perimeter and a confined core.
#
# Notes
#    The center of the reinforcing bars are placed at the inner radius
#    The core concrete ends at the inner radius (same as reinforcing bars)
#    The reinforcing bars are all the same size
#    The center of the section is at (0,0) in the local axis system
#    Zero degrees is along section y-axis
# 
set ri 0.0;				# inner radius of the section
set ro [expr $totalDia/2.0];	# overall (outer) radius of the section
set nfCoreR 32;			# number of radial divisions in the core (number of "rings")
set nfCoreT 36;			# number of theta divisions in the core (number of "wedges")
set nfCoverR 16;			# number of radial divisions in the cover
set nfCoverT 36;			# number of theta divisions in the cover
	
# Define the fiber section
section fiberSec $SecTag  {
	set rc [expr $ro-$clearCover];				# Core radius

 	#patch circ $matTag $numSubdivCirc $numSubdivRad $yCenter $zCenter $intRad $extRad <$startAng $endAng>
	patch circ 4 $nfCoreT $nfCoreR 0 0 $ri $rc 0 360;	# Define the core patch
	patch circ 5 $nfCoverT $nfCoverR 0 0 $rc $ro 0 360;	# Define the cover patch

	#layer circ $matTag $numBar $areaBar $yCenter $zCenter $radius <$startAng $endAng>
	layer circ 6 $numBars $barArea 0 0 $rc;			# Define the reinforcing layer
}

#Add Linear Elastic Torsion to Column Section
set pi [expr 22.0/7.0]
set Jc [expr $pi*pow(($totalDia/2.0),4)/2.0]
set GJc [expr $Gbent*$Jc]
uniaxialMaterial Elastic 100 $GJc
#Section Aggregtor Tag matTag Force Section 
section Aggregator 1 100 T -section $SecTag  

puts "finished creating the lower column section with torsion..."

