puts "Start Eigen Analysis"

# --------------------------------
# EXTRACT NATURAL FREQUENCIES
# --------------------------------
set numModes 12
set lambdaN [eigen $numModes]

# Write modal periods to text file
set outFileID [open $eigFolder/NLFundPeriods.txt w]
for {set i 1} {$i <= $numModes} {incr i 1} {
	set lambda [lindex $lambdaN [expr $i-1]]
	set period [expr 2*3.14/(pow($lambda,0.5))]
	puts "T$i = $period sec"
	puts $outFileID $period
}
close $outFileID

# --------------------------------
# EXTRACT MODESHAPES
# ---------------------------------
# For each mode, extract nodal displacements and rotations at all dofs
for {set i 1} {$i <= $numModes} {incr i 1} {

	set xname "$eigFolder/Mode_$i\x.out";
	set yname "$eigFolder/Mode_$i\y.out";    
	set zname "$eigFolder/Mode_$i\z.out";
	set Rxname "$eigFolder/Mode_$i\Rx.out";
	set Ryname "$eigFolder/Mode_$i\Ry.out";    
	set Rzname "$eigFolder/Mode_$i\Rz.out";

	#recorder Node -file $filename -time -node $nd# -dof $dof# "resp_type"
	set xrec($i) [recorder Node -file $xname -nodeRange 1 99 -dof 1 "eigen $i"]
	set yrec($i) [recorder Node -file $yname -nodeRange 1 99 -dof 2 "eigen $i"]
	set zrec($i) [recorder Node -file $zname -nodeRange 1 99 -dof 3 "eigen $i"]
	set Rxrec($i) [recorder Node -file $Rxname -nodeRange 1 99 -dof 4 "eigen $i"]
	set Ryrec($i) [recorder Node -file $Ryname -nodeRange 1 99 -dof 5 "eigen $i"]
	set Rzrec($i) [recorder Node -file $Rzname -nodeRange 1 99 -dof 6 "eigen $i"]
}
# ----------------------------------------------------------------------
# EIGENVALUE ANALYSIS
# ----------------------------------------------------------------------
wipeAnalysis

system BandGeneral
constraints Transformation
numberer RCM
##                  tolerance maxIter displayCode
test NormDispIncr 1.0e-12      100       0
algorithm Newton
integrator LoadControl 0.1
analysis Static
analyze 1
loadConst -time 0.0 

# Only close recorders associated with eigen analysis
# This allows one to view text output without having to close OpenSEES window
for {set i 1} {$i <= $numModes} {incr i 1} {
	remove recorder $xrec($i)
	remove recorder $yrec($i)
	remove recorder $zrec($i)
	remove recorder $Rxrec($i)
	remove recorder $Ryrec($i)
	remove recorder $Rzrec($i)
}

puts "Finished Eigen Analysis"








