# This file can control convergence in NLRHA

#----------------------------------------------------------------------
#                                                   MATERIAL -ABUTMENT
#                                                  --------------------
# uniaxialMaterial    Elastic   matID      E    
uniaxialMaterial    Elastic       1      $sDX_A;    # global-X
uniaxialMaterial    Elastic       2      $sDY_A;    # global-y
uniaxialMaterial    Elastic       3      $sDZ_A;    # global-z

#----------------------------------------------------------------------
#                                                   MATERIAL -COLUMNS
#                                                  --------------------
# translational spring
uniaxialMaterial    Elastic       21      $sDX_C; 	# global-x
uniaxialMaterial    Elastic       22      $sDY_C; 	# global-y
uniaxialMaterial    Elastic       23      $sDZ_C; 	# global-z

# rotational spring
uniaxialMaterial    Elastic       64      $sRX_C ; 	# global-x
uniaxialMaterial    Elastic       65      $sRY_C ; 	# global-y
uniaxialMaterial    Elastic       66      $sRZ_C ; 	# global-z

#------------Fiber Section---------------------------------------------
# Input Material Properties: These were obtained from the drawings 
# The drawings is in SkwBridgeCADdrawings.pdf and under folder 'Project Documents'
# The calculations for confined properties are documented in ConcreteStressStrainCalc_Skw.m
# The latter file is under 'Skew Bridge\Bin(MATLAB Scripts)\Model Properties'

# Cover concrete
set fc [expr -1.105*144]; 				#Compressive Strength of unConfined Concrete
set ec0 -0.002; 						#Strain at max Stress for unconfined concrete
set fcu [expr $fc*0.20]; 				#Compressive Strength at Ultimate
set ecu -0.005; 						#Strain at Ultimate for unconfined concrete

# Core concrete
set fcc [expr -1.3006*144]; 			#Compressive Strength of Confined Concrete
set ecc0 -0.00377;  					#Strain at max Stress for confined concrete
set fccu [expr -1.1417*144]; 			#Crushing strength for confined concrete
set eccu -0.014793; 					#Crushing strain for confined concrete 

# Rebar steel
set fy [expr 24*144];					#Yield Strength of Longitudinal Steel
set E_st [expr 29000*144]; 				#Young's Modulus for Longitudinal Steel

#Define Material Properties
#Define the Core Concrete
#         matTag   fc   eps0    fcu     epsU
uniaxialMaterial Concrete01 4 $fcc $ecc0 $fccu $eccu
#Define the Cover Concrete
uniaxialMaterial Concrete01 5 $fc $ec0 $fcu $ecu
#Define the Steel
#         matTag   fy   E0    strain-hardening ratio beta
uniaxialMaterial Steel01 6 $fy $E_st 0.01

puts "finished defining the materials..."

