# -----------------------------------
# DEFINE MASS
# -----------------------------------

set eigFolder ModalPushover_1
file mkdir $eigFolder

set MDen   0.0046627;     	# mass density : kips/ft^3/(ft/sec^2)
set g      32.2;           	# gravitational acce: ft/sec^2

# L_ele_# are tributary lengths for span
set L_ele_1   3.25;           # Ele 1 to 2
set L_ele_2   3.295;          # Ele 3 to 19
set L_ele_3   3.29;           # Ele 20 to 38
set L_ele_4   3.334;          # Ele 39 to 78

# L_Bent is tributary lengths for bent
set L_Bent    3.3542;          # bent ele length

set m1      [expr $MDen*$Adeck*$L_ele_1/2];   	# mass per node span 1
set m2      [expr $m1*2];
set mDeck_2 [expr $MDen*$Adeck*$L_ele_2/2];
set m3      [expr $m1 + $mDeck_2]
set mDeck_3 [expr $MDen*$Adeck*$L_ele_3/2];
set mDeck_4 [expr $MDen*$Adeck*$L_ele_4/2];
set mBent   [expr $MDen*$Abent*$L_Bent/2];   	# mass per node span 1
set mCap    [expr $MDen*$Acap*19/2];        	# 19-ele length

#---DECK------------------------------------------------
#===========FIRST HALF OF SPAN==========================
#mass  tag  Mx       My       Mz        Rx     Ry    Rz  
mass    1   $m1      $m1      0.0    0.0    0.0   0.0
mass    2   $m2      $m2      0.0    0.0    0.0   0.0
mass    3   $m3      $m3      0.0    0.0    0.0   0.0
set mList [list $m1 $m2 $m3]

for {set i 4} {$i <= 19} {incr i 1} {
	set m [expr $mDeck_2*2]
	mass    $i   $m      $m       0.0    0.0     0.0   0.0
	lappend mList $m
}

set m20 [expr $mDeck_2 + $mDeck_3]
mass  20   $m20   $m20    0.0    0.0     0.0   0.0
lappend mList $m20

for {set i 21} {$i <= 38} {incr i 1} {
 	set m [expr $mDeck_3*2]
	mass    $i   $m      $m       0.0    0.0     0.0   0.0
	lappend mList $m
}

set m39 [expr ($mDeck_3+$mDeck_4+$mCap*2)]
mass    39  $m39  $m39   0.0    0.0  0.0   0.0
lappend mList $m39

#===========SECOND HALF OF SPAN=======================
for {set i 40} {$i <= 78} {incr i 1} {
 	set m [expr $mDeck_4*2]
	mass   $i   $m       $m       0.0    0.0     0.0   0.0
	lappend mList $m
}

set m79 [expr $mDeck_4 + $m1]
set m80 [expr $m1*2]
set m81 [expr $m1]
mass    79  $m79  $m79  0.0    0.0    0.0   0.0
mass    80  $m80  $m80  0.0    0.0    0.0   0.0
mass    81  $m81  $m81  0.0    0.0    0.0   0.0
lappend mList $m79 $m80 $m81 

#----BENT (NORTH)-------------------------------------
mass    82  $mBent  $mBent  0.0    0.0    0.0   0.0
lappend mList $mBent

for {set i 83} {$i<=89} {incr i 1} {
	set m [expr $mBent*2]
	mass $i   $m   $m   0.0  0.0  0.0  0.0
	lappend mList $m
}

set    m90  [expr $mBent+$mCap]
mass    90  $m90  $m90  0.0     0.0    0.0   0.0
lappend mList $m90

#---BENT (SOUTH)-------------------------------------
mass    91 $mBent  $mBent  0.0     0.0    0.0   0.0
lappend mList $mBent

for {set i 92} {$i<=98} {incr i 1} {
 	set m [expr $mBent*2]
	mass $i   $m   $m   0.0  0.0  0.0  0.0
	lappend mList $m
}

set    m99  [expr $mBent+$mCap]
mass    99  $m99  $m99  0.0    0.0    0.0   0.0
lappend mList $m99
#====================================================

# Check size of mass vector
#puts "size of mass vec is [llength $mList]"

# Write mass vector for post processing
set fid [open $eigFolder/massList.txt w]
puts $fid $mList
close $fid

# Determine total mass
set mtotal 0
foreach m $mList {
	set mtotal [expr $mtotal+$m]
}
set WTtotal [expr $mtotal*$g];

puts "Total mass is $mtotal kips/(ft/sec^2)"
puts "Total weight of structure is $WTtotal kips"

#Simpler calculation of total mass as a check
#set mtotal2 [expr $MDen*($Adeck*265.063+$Abent*26.8333*2+$Acap*19*2)];
#puts "Total mass check is $mtotal2 kips/(ft/sec^2)"

puts "finished assigning masses..."





