# PAINTER STREET OVERCROSSING 
# Units are in feet
#====================================================================
#set AnalysisOption "Eigen";             	# Eigen Analysis
set AnalysisOption "Static";             # Pushover Analysis
#set AnalysisOption "CyclicPush"; 		# Cyclic Pushover Analysis
#set AnalysisOption "Dynamic";            # Time History Analysis

wipe all;
model BasicBuilder -ndm 3 -ndf 6

#-----------------------------------
# CORRECTION COEFFICIENTS
#-----------------------------------
#-------Trial of any combination------------------
set coef_bc   1.0;      # for B.C.
set coef_bcBent  1.0 ;      # for B.C.
set c_Damp    0.0 ;      # for Damping coefficient
set c_Bent    1.0;       # for upper part of bent geometry

source assignNodes.tcl
source setSectionProperties.tcl
source setSpringStiffness.tcl
source assignMaterial.tcl
source assignBoundaryConditions.tcl
source assignGeoTran.tcl
source setFiberSection.tcl

#Assign elements in separate files
source assignDeck.tcl
source assignBentNorthNL.tcl
source assignBentSouthNL.tcl
source assignCapBeam.tcl
puts "finished assigning the elements..."

source assignMass.tcl

puts "model complete!!"

source GravityAnalysis.tcl

if {$AnalysisOption == "Eigen"} {
	source Eigen.tcl
}
if {$AnalysisOption == "Static"} {
	# Longitudinal direction
	source pushover1.tcl
}
if {$AnalysisOption == "CyclicPush"} {
	source AnalysisStatic.tcl
}
if {$AnalysisOption == "Dynamic"} {
	source dynamic.tcl
}

#====================================================================
#                                DONE !!!!
#====================================================================

