###############################################################################################
#Start Modeling the Lateral Pushover Loads in MODE n DIRECTION

set modeNum 2
set drift 0.016
set cntrlNode 39

pattern Plain 2 Linear {
	set eigFileID  [open $eigFolder/Mode_$modeNum\x.out r]
	gets $eigFileID line
	set modex  [split $line]
	close $eigFileID

	set eigFileID  [open $eigFolder/Mode_$modeNum\y.out r]
	gets $eigFileID  line
	set modey  [split $line]
	close $eigFileID
	
	set i 1
	foreach m $mList phix $modex phiy $modey {
		#  node	Fx	Fy	Fz 	  Mx	My  Mz
		set Hx  [expr $m*$phix ]
		set Hy  [expr $m*$phiy ]
		load $i $Hx $Hy 0.0 0.0 0.0 0.0 
		incr i 1
	}
} 	
puts "finished creating the lateral loads for mode $modeNum direction..."

#----------------------------------------------------------------------
#                                                   PUSHOVER ANALYSIS
#----------------------------------------------------------------------

wipeAnalysis
puts "pushover analysis for TRANSVERSE direction starts"

# Put pushover output in same directory as eigen output 
set recTag1 [recorder Node -file $eigFolder/MasterNodeDisp_Trans.out -time -node $cntrlNode -dof 1 2 disp]
set recTag2 [recorder Node -file $eigFolder/Reactions_Trans.out -node 1 81 82 91 -dof 1 2 3 reaction]

set height 26.8333
set maxU [expr $height*$drift]
set dU [expr $maxU/200.0]

constraints Transformation
numberer RCM		
system BandGeneral
test EnergyIncr 1.0e-12 100
algorithm NewtonLineSearch

integrator DisplacementControl $cntrlNode 2 $dU
analysis Static

#set currentDisp [nodeDisp $cntrlNode 2]
#set ok 0
#while {$ok == 0 && $currentDisp < $maxU} {
#	set ok [analyze 1]
#	if {$ok != 0} {
#	test EnergyIncr 1.0e-12 1000
#	algorithm ModifiedNewton -initial
#	set ok [analyze 1]
#		if {$ok == 0} {
#			test EnergyIncr 1.0e-4 100
#			algorithm NewtonLineSearch
#		}
#	}
#
#	if {$ok != 0} {
#		integrator DisplacementControl $cntrlNode 2 [expr $dU/10.0]
#		set ok [analyze 1]
#		integrator DisplacementControl $cntrlNode 2 $dU
#	}
#	
#	set currentDisp [nodeDisp $cntrlNode 2]
#}

set numSteps [expr int($maxU/$dU)]
analyze $numSteps

remove recorder $recTag1
remove recorder $recTag2

################################################################
# Compute mode properties
################################################################
set Ln 0
set Mn 0
foreach m $mList phix $modex phiy  $modey {
	set Ln [expr $Ln+($m*$phiy)]
	set Mn [expr $Mn+($m*$phix*$phix)+($m*$phiy*$phiy)]
}

set Gamman [expr $Ln/$Mn]
set phiMasterNode [lindex $modey  38]
set Mneff [expr $Gamman*$Ln]
set rnBar [expr $Mneff/$mtotal*100]

puts "Mn for mode $modeNum is: $Mn"
puts "Modal participation factor for mode $modeNum is: $Gamman"
puts "Modal displacement for master node is: $phiMasterNode"
puts "Effective modal mass for mode $modeNum is: $Mneff kips-sec^2/ft"
puts "Percentage of static contribution for mode $modeNum is: $rnBar"
puts "Pushover Analysis is complete!!!"