
#----------------------------------------------------------------------
# UPPER BENT COLUMN SECTION                                                 
#----------------------------------------------------------------------
# Back calculate average total diameter from area
set totalDia_u [expr pow($Abent_u*4/3.14,0.5)]; 	# Column Diameter
set clearCover_u [expr 2.0/12];				# Column cover to reinforcing steel NA.
set numBars_i 36;							# number of inner longitudinal-reinforcement bars
set numBars_o 18;							# number of outer longitudinal-reinforcement bars
set barArea_i [expr 1.56/144];				# area of inner bars
set barArea_o [expr 0.31/144];				# area of outer bars
set SecTag_u 12;							# set tag for symmetric section

# Generate a circular reinforced concrete section
# with two layers of steel and two confined cores.
# 
#
# Notes
#    The center of the reinforcing bars are placed at the inner and outer radii
#    The core concrete ends at the outer radius (same as reinforcing bars on outer radius)
#    The reinforcing bars are all the same size for a given radius
#    The center of the section is at (0,0) in the local axis system
#    Zero degrees is along section y-axis
# 
set ri_u [expr (3.0+8.75/12)/2];	# inner core radius
set ro_u [expr $totalDia_u/2];	# overall (outer) radius of the section
set nfCoreR_i 32;				# number of radial divisions in the inner core (number of "rings")
set nfCoreT_i 36;				# number of theta divisions in the inner core (number of "wedges")
set nfCoreR_o 16;				# number of radial divisions in the outer core (number of "rings")
set nfCoreT_o 18;				# number of theta divisions in the outer core (number of "wedges")
set nfCoverR_u 8;				# number of radial divisions in the cover
set nfCoverT_u 18;			# number of theta divisions in the cover

# Define the fiber section
section fiberSec $SecTag_u {
	set rc_u [expr $ro_u-$clearCover_u];				# outer core radius

 	#patch circ $matTag $numSubdivCirc $numSubdivRad $yCenter $zCenter $intRad $extRad <$startAng $endAng>
	patch circ 4 $nfCoreT_i $nfCoreR_i 0 0 0 $ri_u 0 360;		# Define the inner core patch
	patch circ 4 $nfCoreT_o $nfCoreR_o 0 0 $ri_u $rc_u 0 360;	# Define the outer core patch
	patch circ 5 $nfCoverT_u $nfCoverR_u 0 0 $rc_u $ro_u 0 360;	# Define the cover patch

	#layer circ $matTag $numBar $areaBar $yCenter $zCenter $radius <$startAng $endAng>
	layer circ 6 $numBars_i $barArea_i 0 0 $ri_u;			# Define the inner reinforcing layer
	layer circ 6 $numBars_o $barArea_o 0 0 $rc_u;			# Define the outer reinforcing layer
}

#Add Linear Elastic Torsion to Column Section
set pi [expr 22.0/7.0]
set Jc [expr $pi*pow(($totalDia_u/2),4)/2]
set GJc [expr $Gbent*$Jc]
uniaxialMaterial Elastic 101 $GJc
#Section Aggregtor Tag matTag Force Section 
section Aggregator 2 101 T -section $SecTag_u  

puts "finished creating the upper column section with torsion..."
