% This file is used in response_TCL_NGA.m
% Function to create .PSA and .SD files for future plotting of spectra
%
% Written by: E.Kalkan
% Modified by: N.Kwong
% Date Modified: 09 Nov 2010
%% ----------------------DEFINITIONS---------------------------------------
% fpath          = specifies location for placement of .PSA and .SD files
% filename_c     = name of GM file without file extensions
% sPeriod        = vector containing periods of interest for spectrum
% pseudo_acc_max = Pseudo spectral acceleration (cm/sec)
% displ_max      = Spectral relative displacement (cm)
%
% Note: Units are specified by gacc file (not necessarily cm)

%% ------------------------------------------------------------------------
function createSpecFiles(fpath, filename_c,sPeriod,pseudo_acc_max,displ_max)
    filename1 = strcat(fpath,filename_c,'.PSA');
    fid1 = fopen (filename1,'w');
    output1 =  [sPeriod'  pseudo_acc_max'];
    fprintf(fid1, '%s %s \n','Filename:',filename_c);
    fprintf(fid1, '%s \n','T(sec) PSA (cm/sec^2)');
    fprintf(fid1, '%s \n','----------------');
    fprintf(fid1,'%4.3f %8.5f\n',output1');
    fclose(fid1);

    filename2 = strcat(fpath,filename_c,'.SD');
    fid2 = fopen (filename2,'w');
    output2 =  [sPeriod'  displ_max'];
    fprintf(fid2, '%s %s \n','Filename:',filename_c);
    fprintf(fid2, '%s \n','T(sec) SD(cm)');
    fprintf(fid2, '%s \n','----------------');
    fprintf(fid2,'%4.3f %8.5f\n',output2');
    fclose(fid2);
end