function [fa, fb, bandwidth] = fftPlot(acc,dt)
    a1 = length(acc);
    [freq, faplota]=fourier(acc,dt);
    period = freq.^-1;
    
    % Plot normalized Fourier Spectra 
    subplot(2,1,1)
    semilogx(period,faplota./a1,'r-o');
    xlabel('Period'); ylabel('FAA Amplitude');
    tpeak = peaktime (faplota./a1);
    hold;  semilogx([period(tpeak) period(tpeak)],[0 2.5]);
    fprintf('Peak time = %5.3f \n',period(tpeak));
    tit1 = strcat('Tp = ',num2str(period(tpeak)),' sec');
    text('pos',[0.01 1.0],'str',tit1,'FontSize',[10],'FontWeight','bold');
    
    % Plot smoothed Fourier Spectra
    faplotaSmooth = moving_average(faplota./a1,10);
    subplot(2,1,2)
    semilogx(period,faplotaSmooth,'g-o');
    xlabel('Period'); ylabel('FAA Amplitude');
    peak = max(faplotaSmooth);
    FAA_bandwidth = 1/sqrt(2)*peak;

    % Get bandwidth / dispersion
    for i=2:length(freq)
        if (faplotaSmooth(i)>FAA_bandwidth && faplotaSmooth(i-1)<FAA_bandwidth)
            fa = freq(i);
        end
        if (faplotaSmooth(i)<FAA_bandwidth && faplotaSmooth(i-1)>FAA_bandwidth)
            fb = freq(i);
        end
    end
    bandwidth = fb-fa;        
    tit2 = strcat('Bandwidth = ',num2str(bandwidth),' Hz');
    text('pos',[0.01 1.0],'str',tit2,'FontSize',[10],'FontWeight','bold');
    X1 = [period(1) period(end)]; Y1 = [FAA_bandwidth FAA_bandwidth];
    X2 = [fa^-1 fa^-1]; X3 = [fb^-1 fb^-1]; Y2 = [0 FAA_bandwidth];
    line(X1,Y1,'Color','k','LineWidth',2.0);
    line(X2,Y2,'LineStyle','--'); line(X3,Y2,'LineStyle','--');
    
return
    