% This file is used in calcSpectrum function
% Function to calculate displacement & velocity response histories
%
% Written by: E.Kalkan
% Modified by: N.Kwong
% Date Modified: 17 Oct 2010
%% ----------------------DEFINITIONS---------------------------------------
% wn    = natural circular frequency in rad/sec^2
% xi    = damping ratio
% dt    = time step in ground acceleration file
% gacc  = ground acceleration file
% N     = number of data points
% y     = matrix for response histories
% C     = equivalent viscous damping of SDF system
% K     = stiffness of SDF system
% displ = relative displacement response history
% veloc = relative velocity response history
%
% Note: Units are specified by gacc file (not necessarily cm)

%% ------------------------------------------------------------------------
function [displ,veloc] = solveLESDF(wn,xi,dt,gacc)
N = length(gacc);
y = zeros(2,N);
C = 2*xi*wn;
K = wn^2;
% Set initial displacement and velocity
y(:,1) = [0;0];
A = [0 1; -K -C]; Ae = expm(A*dt); AeB = A\(Ae-eye(2))*[0;1];
for k = 2:N;
    y(:,k) = Ae*y(:,k-1) + AeB*gacc(k);
end
displ = (y(1,:))';                      
veloc = (y(2,:))';                      
end